@@ -2,7 +2,6 @@
 #define BLACKBOX_H
 
 #include "kernel/mod2.h"
-#include "omalloc/omalloc.h"
 
 #include "kernel/structs.h"
 
@@ -49,7 +48,7 @@ struct  blackbox_struct
   BOOLEAN (*blackbox_deserialize)(blackbox **b,void **d, si_link f);
   /// additional type info
   void *data;
-  /// addtinional gneral properties
+  /// additional general properties
   int properties; // bit 0:blackbox is only a wrapper for lists
 #define  BB_LIKE_LIST(B) ((B)->properties &1)
 } ;
@@ -81,4 +80,13 @@ int setBlackboxStuff(blackbox *bb,const char *name);
 /// list all defined type (for debugging)
 void printBlackboxTypes();
 
+/// struct for containing list of blackbox names and the number of them.
+struct blackbox_list {
+	int count;
+	void **list;
+};
+
+/// return array of all define types.
+struct blackbox_list *getBlackboxTypes();
+
 #endif
