@@ -4,7 +4,7 @@
 *  Computer Algebra System SINGULAR     *
 ****************************************/
 /*
-* ABSTRACT - interupt and signal handling
+* ABSTRACT - interrupt and signal handling
 */
 #include <setjmp.h>
 #include "kernel/mod2.h"
@@ -24,4 +24,9 @@ EXTERN_VAR volatile int defer_shutdown;
 
 void si_set_signals();
 void si_reset_signals();
+void sig_term_hdl_child(int /*sig*/);
+void sig_term_hdl(int /*sig*/);
+
+typedef void (*si_hdl_typ)(int);
+si_hdl_typ si_set_signal ( int sig, si_hdl_typ signal_handler);
 #endif
