@@ -1,7 +1,7 @@
 #ifndef NFORDER_ELT_HPP
 #define NFORDER_ELT_HPP
 
-extern n_coeffType nforder_type;
+EXTERN_VAR n_coeffType nforder_type;
 
 number EltCreateMat(nforder *a, bigintmat *b);
 
