@@ -1,9 +1,7 @@
-#include <kernel/ideals.h>
-#include <polys/monomials/p_polys.h>
+#include "kernel/ideals.h"
+#include "polys/monomials/p_polys.h"
 
-#include <gfanlib/gfanlib.h>
-
-#include <exception>
+#include "gfanlib/gfanlib.h"
 
 long wDeg(const poly p, const ring r, const gfan::ZVector &w)
 {
