@@ -4,7 +4,7 @@
 #include "Singular/ipid.h"
 
 
-extern int tropicalVerboseLevel;
+EXTERN_VAR int tropicalVerboseLevel;
 
 
 gfan::ZCone maximalGroebnerCone(const ideal &I, const ring &r);
