@@ -1,15 +1,14 @@
-#include <gfanlib/gfanlib_matrix.h>
-#include <gfanlib/gfanlib_zcone.h>
-#include <polys/monomials/p_polys.h>
-#include <callgfanlib_conversion.h>
-#include <std_wrapper.h>
-#include <containsMonomial.h>
-#include <initial.h>
-#include <witness.h>
-#include <tropicalStrategy.h>
-#include <tropicalVarietyOfPolynomials.h>
-#include <tropicalCurves.h>
-#include <set>
+#include "gfanlib/gfanlib_matrix.h"
+#include "gfanlib/gfanlib_zcone.h"
+#include "polys/monomials/p_polys.h"
+#include "callgfanlib_conversion.h"
+#include "std_wrapper.h"
+#include "containsMonomial.h"
+#include "initial.h"
+#include "witness.h"
+#include "tropicalStrategy.h"
+#include "tropicalVarietyOfPolynomials.h"
+#include "tropicalCurves.h"
 
 /***
  * Given two sets of cones A,B and a dimensional bound d,
