@@ -1,7 +1,7 @@
 #ifndef TROPICAL_TRAVERSAL_H
 #define TROPICAL_TRAVERSAL_H
 
-#include <groebnerCone.h>
+#include "groebnerCone.h"
 
 groebnerCones tropicalTraversalMinimizingFlips(const groebnerCone startingCone);
 groebnerCones tropicalTraversal(const groebnerCone startingCone);
