@@ -10,7 +10,7 @@
 
 #include "gfanlib/gfanlib_zfan.h"
 
-BITSET bitsetSave1, bitsetSave2;
+VAR BITSET bitsetSave1, bitsetSave2;
 
 
 /***
