@@ -1,7 +1,7 @@
 #ifndef POLY_WRAP_HEADER
 #define POLY_WRAP_HEADER
 #include <boost/python.hpp>
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 #include "Poly.h"
 void export_poly();
 boost::python::str Poly_as_str(const Poly& p);
