@@ -1,5 +1,5 @@
 #include "kernel/mod2.h"
-#ifdef HAVE_PYTHON_MOD
+#ifdef HAVE_PYTHON
 #include <boost/python.hpp>
 #include "Singular/ipshell.h"
 #include "ring_wrap.h"
@@ -19,7 +19,7 @@ void ring_set(Ring & R)
     if (h==NULL)
     {
       char name_buffer[100];
-      static int ending=0;
+      STATIC_VAR int ending=0;
       ending++;
       sprintf(name_buffer, "PYTHON_RING_VAR%d",ending);
       h=enterid(name_buffer,0,RING_CMD,&IDROOT);
