@@ -7,14 +7,14 @@
 * ABSTRACT: Declarations for working with Options
 */
 
-#include "Singular/fegetopt.h"
+#include "resources/fegetopt.h"
 
 #include "Singular/feOptTab.h"
 
 extern const char SHORT_OPTS_STRING[];
 
 /* specifies format of options */
-extern struct fe_option feOptSpec[];
+EXTERN_VAR struct fe_option feOptSpec[];
 
 /* provides feOptIndex enum type for fast accesses to feOptSpec */
 #if ! defined(GENERATE_DEPEND)
@@ -62,7 +62,7 @@ inline int feOptValue(feOptIndex opt, int* val)
   return FALSE;
 }
 
-// maps name to otions
+// maps name to options
 feOptIndex feGetOptIndex(const char* name);
 feOptIndex feGetOptIndex(int optc);
 
