@@ -42,8 +42,8 @@ enum noeof_t
   noeof_string
 };  /* for scanner.l */
 
-extern int yylineno;
-extern char my_yylinebuf[80];
+EXTERN_VAR int yylineno;
+EXTERN_VAR char my_yylinebuf[80];
 extern const char sNoName_fe[];
 
 #ifdef __cplusplus
@@ -70,6 +70,7 @@ class Voice
     long   fptr;          // current position in buffer
     long   ftellptr;      // with glibc 2.22, file position gets lost
                           // in sig_chld_hdl (ssi:ffork link), see examples/waitall.sing
+    int buff_size;        // malloc size of buffer
 
     int    start_lineno;  // lineno, to restore in recursion
     int    curr_lineno;   // current lineno
@@ -88,11 +89,12 @@ class Voice
   void Next();
 } ;
 
-extern Voice  *currentVoice;
+EXTERN_VAR Voice  *currentVoice;
 
 Voice * feInitStdin(Voice *pp);
 
 const  char * VoiceName();
+int VoiceLine();
 void    VoiceBackTrack();
 BOOLEAN contBuffer(feBufferTypes typ);
 BOOLEAN exitBuffer(feBufferTypes typ);
