@@ -8,13 +8,13 @@
 #ifndef GMS_H
 #define GMS_H
 
-#include <kernel/mod2.h>
-#include <polys/matpol.h>
+#include "kernel/mod2.h"
+#include "polys/matpol.h"
 
-#include <kernel/structs.h>
-#include <kernel/ideals.h>
+#include "kernel/structs.h"
+#include "kernel/ideals.h"
 
-#include <Singular/lists.h>
+#include "Singular/lists.h"
 
 lists gmsNF(ideal p, ideal g, matrix B, int D, int K);
 BOOLEAN gmsNF(leftv res, leftv h);
