@@ -17,6 +17,7 @@
 #include "coeffs/coeffs.h"
 #include "coeffs/numbers.h"
 #include "coeffs/bigintmat.h"
+#include "coeffs/longrat.h"
 
 
 #include "polys/ext_fields/algext.h"
@@ -67,7 +68,7 @@ static BOOLEAN jjCOLMAX(leftv, leftv a)
 static BOOLEAN jjTIMER(leftv, leftv a)
 {
   timerv=(int)((long)(a->Data()));
-  initTimer();
+  startTimer();
   return FALSE;
 }
 #ifdef HAVE_GETTIMEOFDAY
@@ -680,17 +681,19 @@ static BOOLEAN jiA_BIGINT(leftv res, leftv a, Subexpr e)
       return TRUE;
     }
     bigintmat *iv=(bigintmat *)res->data;
-    if (e->next==NULL)
+    if ((e->next==NULL)&&(res->rtyp==BIGINTMAT_CMD))
     {
       WerrorS("only one index given");
       return TRUE;
     }
     else
     {
-      int c=e->next->start;
+      int c;
+      if (res->rtyp==BIGINTMAT_CMD) c=e->next->start;
+      else { c=i+1; i=0;}
       if ((i>=iv->rows())||(c<1)||(c>iv->cols()))
       {
-        Werror("wrong range [%d,%d] in bigintmat %s(%d,%d)",i+1,c,res->Name(),iv->rows(),iv->cols());
+        Werror("wrong range [%d,%d] in bigintmat/bigintvec %s(%d,%d)",i+1,c,res->Name(),iv->rows(),iv->cols());
         return TRUE;
       }
       else
@@ -703,6 +706,68 @@ static BOOLEAN jiA_BIGINT(leftv res, leftv a, Subexpr e)
   jiAssignAttr(res,a);
   return FALSE;
 }
+static BOOLEAN jiA_BIGINT_N(leftv res, leftv a, Subexpr e)
+{
+  number p=(number)a->Data();
+  number pp=NULL;
+  if (currRing->cf->rep==n_rep_gap_rat)
+  {
+    if (SR_HDL(a) & SR_INT) pp=p;
+    else if (p->s==3) pp=nCopy(p);
+    else
+    {
+      WerrorS("cannot assign to bigint");
+      return TRUE;
+    }
+  }
+  else if (currRing->cf->rep==n_rep_gmp)
+    pp=coeffs_BIGINT->cfInitMPZ((mpz_ptr)p,coeffs_BIGINT);
+  else if (currRing->cf->rep==n_rep_int)
+    pp=coeffs_BIGINT->cfInit((long)p,coeffs_BIGINT);
+  else
+  {
+    WerrorS("cannot assign to bigint");
+    return TRUE;
+  }
+  if (e==NULL)
+  {
+    if (res->data!=NULL) n_Delete((number *)&res->data,coeffs_BIGINT);
+    res->data=(void*)pp;
+  }
+  else
+  {
+    int i=e->start-1;
+    if (i<0)
+    {
+      Werror("index[%d] must be positive",i+1);
+      return TRUE;
+    }
+    bigintmat *iv=(bigintmat *)res->data;
+    if ((e->next==NULL)&&(res->rtyp==BIGINTMAT_CMD))
+    {
+      WerrorS("only one index given");
+      return TRUE;
+    }
+    else
+    {
+      int c;
+      if (res->rtyp==BIGINTMAT_CMD) c=e->next->start;
+      else { c=i+1; i=0;}
+      if ((i>=iv->rows())||(c<1)||(c>iv->cols()))
+      {
+        Werror("wrong range [%d,%d] in bigintmat/bigintvec %s(%d,%d)",i+1,c,res->Name(),iv->rows(),iv->cols());
+        return TRUE;
+      }
+      else
+      {
+        n_Delete((number *)&BIMATELEM(*iv,i+1,c),iv->basecoeffs());
+        BIMATELEM(*iv,i+1,c) = pp;
+      }
+    }
+  }
+  jiAssignAttr(res,a);
+  return FALSE;
+}
 static BOOLEAN jiA_LIST_RES(leftv res, leftv a,Subexpr)
 {
   syStrategy r=(syStrategy)a->CopyD(RESOLUTION_CMD);
@@ -904,10 +969,40 @@ static BOOLEAN jiA_INTVEC(leftv res, leftv a, Subexpr)
   }
 #endif
 }
+static BOOLEAN jiA_INTVEC_BI(leftv res, leftv a, Subexpr)
+{
+  //Warn("bigintvec -> intvec in >>%s<<",my_yylinebuf);
+  if (res->data!=NULL) delete ((intvec *)res->data);
+  bigintmat *b=(bigintmat*)a->Data();
+  intvec *iv=new intvec(1,b->cols());
+  for(int i=0;i<b->cols();i++)
+  {
+    (*iv)[i]=n_Int(BIMATELEM(*b,1,i+1),coeffs_BIGINT);
+  }
+   res->data=(void *)iv;
+  jiAssignAttr(res,a);
+  return FALSE;
+}
 static BOOLEAN jiA_BIGINTMAT(leftv res, leftv a, Subexpr)
 {
   if (res->data!=NULL) delete ((bigintmat *)res->data);
-  res->data=(void *)a->CopyD(BIGINTMAT_CMD);
+  res->data=(void *)a->CopyD();
+  jiAssignAttr(res,a);
+  return FALSE;
+}
+static BOOLEAN jiA_BIGINTVEC_IV(leftv res, leftv a, Subexpr)
+{
+  if (res->data!=NULL) delete ((bigintmat *)res->data);
+  intvec *aa=(intvec*)a->Data();
+  int l=aa->rows();
+  bigintmat* bim=new bigintmat(1,l,coeffs_BIGINT);
+  for(int i=0;i<l;i++)
+  {
+    number tp = n_Init((*aa)[i], coeffs_BIGINT);
+    n_Delete(&BIMATELEM((*bim),1,i+1), coeffs_BIGINT);
+    BIMATELEM((*bim),1,i+1)=tp;
+  }
+  res->data=(void*)bim;
   jiAssignAttr(res,a);
   return FALSE;
 }
@@ -930,8 +1025,7 @@ static BOOLEAN jiA_IDEAL(leftv res, leftv a, Subexpr)
   if (errorreported) return TRUE;
   if (res->data!=NULL) idDelete((ideal*)&res->data);
   res->data=(void*)I;
-  if (a->rtyp==IDHDL) id_Normalize((ideal)a->Data(), currRing);
-  else                id_Normalize(I/*(ideal)res->data*/, currRing);
+  if (a->rtyp!=IDHDL) id_Normalize(I, currRing);
   jiAssignAttr(res,a);
   if (((res->rtyp==IDEAL_CMD)||(res->rtyp==MODUL_CMD))
   && (IDELEMS(I/*(ideal)(res->data)*/)==1)
@@ -963,8 +1057,11 @@ static BOOLEAN jiA_MODUL_P(leftv res, leftv a, Subexpr)
   ideal I=idInit(1,1);
   I->m[0]=(poly)a->CopyD(POLY_CMD);
   if (errorreported) return TRUE;
-  if (I->m[0]!=NULL) pSetCompP(I->m[0],1);
-  pNormalize(I->m[0]);
+  if (I->m[0]!=NULL)
+  {
+    pSetCompP(I->m[0],1);
+    if(a->rtyp!=IDHDL) pNormalize(I->m[0]);
+  }
   if (res->data!=NULL) idDelete((ideal*)&res->data);
   res->data=(void *)I;
   if (TEST_V_QRING && (currRing->qideal!=NULL))
@@ -984,7 +1081,7 @@ static BOOLEAN jiA_IDEAL_M(leftv res, leftv a, Subexpr)
   IDELEMS((ideal)m)=MATROWS(m)*MATCOLS(m);
   ((ideal)m)->rank=1;
   MATROWS(m)=1;
-  id_Normalize((ideal)m, currRing);
+  if (a->rtyp!=IDHDL) id_Normalize((ideal)m, currRing);
   if (res->data!=NULL) idDelete((ideal*)&res->data);
   res->data=(void *)m;
   if (TEST_V_QRING && (currRing->qideal!=NULL))
@@ -1004,7 +1101,7 @@ static BOOLEAN jiA_IDEAL_Mo(leftv res, leftv a, Subexpr)
     return TRUE;
   }
   if (res->data!=NULL) idDelete((ideal*)&res->data);
-  id_Normalize(m, currRing);
+  if (a->rtyp!=IDHDL) id_Normalize(m, currRing);
   id_Shift(m,-1,currRing);
   m->rank=1;
   res->data=(void *)m;
@@ -1250,7 +1347,7 @@ static BOOLEAN jiAssign_1(leftv l, leftv r, int rt, BOOLEAN toplevel, BOOLEAN is
   {
     if ((!TEST_V_ASSIGN_NONE)||(lt!=DEF_CMD))
     {
-      WarnS("right side is not a datum, assignment ignored");
+      Warn("right side is not a datum, assignment to `%s` ignored",l->Name());
       Warn("in line >>%s<<",my_yylinebuf);
       // if (!errorreported)
       //   WerrorS("right side is not a datum");
@@ -1719,6 +1816,45 @@ static BOOLEAN jjA_L_BIGINTMAT(leftv l,leftv r,bigintmat *bim)
   IDBIMAT((idhdl)l->data)=bim;
   return FALSE;
 }
+static BOOLEAN jjA_L_BIGINTVEC(leftv l,leftv r,bigintmat *bim)
+{
+  /* left side is bigintvec, right side is list (of int,intvec,intmat)*/
+  leftv hh=r;
+  int i = 0;
+  delete bim;
+  bim=new bigintmat(1,exprlist_length(r),coeffs_BIGINT);
+  while (hh!=NULL)
+  {
+    if (i>=bim->cols())
+    {
+      if (traceit&TRACE_ASSIGN)
+      {
+        Warn("expression list length(%d) does not match bigintvec size(%d)",
+              exprlist_length(hh),bim->cols());
+      }
+      break;
+    }
+    if (hh->Typ() == INT_CMD)
+    {
+      number tp = n_Init((int)((long)(hh->Data())), coeffs_BIGINT);
+      bim->set(i++, tp);
+      n_Delete(&tp, coeffs_BIGINT);
+    }
+    else if (hh->Typ() == BIGINT_CMD)
+    {
+      bim->set(i++, (number)(hh->Data()));
+    }
+    else
+    {
+      delete bim;
+      return TRUE;
+    }
+    hh = hh->next;
+  }
+  if (IDBIMAT((idhdl)l->data)!=NULL) delete IDBIMAT((idhdl)l->data);
+  IDBIMAT((idhdl)l->data)=bim;
+  return bim==NULL;
+}
 static BOOLEAN jjA_L_STRING(leftv l,leftv r)
 {
   /* left side is string, right side is list of string*/
@@ -2058,6 +2194,7 @@ BOOLEAN iiAssign(leftv l, leftv r, BOOLEAN toplevel)
       /* a = ... */
       if ((lt!=MATRIX_CMD)
       &&(lt!=BIGINTMAT_CMD)
+      &&(lt!=BIGINTVEC_CMD)
       &&(lt!=CMATRIX_CMD)
       &&(lt!=INTMAT_CMD)
       &&((lt==rt)||(lt!=LIST_CMD)))
@@ -2079,6 +2216,7 @@ BOOLEAN iiAssign(leftv l, leftv r, BOOLEAN toplevel)
       if (((lt!=LIST_CMD)
         &&((rt==MATRIX_CMD)
           ||(rt==BIGINTMAT_CMD)
+          ||(rt==BIGINTVEC_CMD)
           ||(rt==CMATRIX_CMD)
           ||(rt==INTMAT_CMD)
           ||(rt==INTVEC_CMD)
@@ -2144,6 +2282,11 @@ BOOLEAN iiAssign(leftv l, leftv r, BOOLEAN toplevel)
       b=jjA_L_INTVEC(l,r,new intvec(IDINTVEC((idhdl)l->data)));
       break;
     }
+    case BIGINTVEC_CMD:
+    {
+      b=jjA_L_BIGINTVEC(l, r, new bigintmat(IDBIMAT((idhdl)l->data)));
+      break;
+    }
     case BIGINTMAT_CMD:
     {
       b=jjA_L_BIGINTMAT(l, r, new bigintmat(IDBIMAT((idhdl)l->data)));
