@@ -91,6 +91,13 @@ static void * iiBI2V(void *data)
   return (void *)p;
 }
 
+static void * iiIV2BIV(void *data)
+{
+  intvec *aa=(intvec*)data;
+  bigintmat* bim=iv2biv(aa,coeffs_BIGINT);
+  return (void *)bim;
+}
+
 static void * iiI2Id(void *data)
 {
   ideal I=idInit(1,1);
@@ -209,6 +216,14 @@ static void * iiI2BI(void *data)
   return (void *)n;
 }
 
+static void * iiI2BIV(void *data)
+{
+  number n=n_Init((int)(long)data, coeffs_BIGINT);
+  bigintmat *b=new bigintmat(1,1,coeffs_BIGINT);
+  n_Delete(&((*b)[0]),coeffs_BIGINT);
+  (*b)[0]=n;
+  return (void *)b;
+}
 #ifdef SINGULAR_4_2
 static void * iiI2NN(void *data)
 {
@@ -476,8 +491,8 @@ BOOLEAN iiConvert (int inputType, int outputType, int index, leftv input, leftv
             }
             else
             {
-              char *tmp=(char *)omAlloc(4);
-              sprintf(tmp,"%c%d",*(currRing->names[nr-1]),
+              char *tmp=(char *)omAlloc(8);
+              snprintf(tmp,8,"%c%d",*(currRing->names[nr-1]),
                 (int)pGetExp((poly)input->data,nr));
               output->name=tmp;
             }
