@@ -21,8 +21,8 @@
 // They are more difficult to clean up after a process crash
 // but are supported more widely.
 
-sipc_sem_t *semaphore[SIPC_MAX_SEMAPHORES];
-int sem_acquired[SIPC_MAX_SEMAPHORES];
+VAR sipc_sem_t *semaphore[SIPC_MAX_SEMAPHORES];
+VAR int sem_acquired[SIPC_MAX_SEMAPHORES];
 
 /* return 1 on success,
  *        0 if already initialized,
@@ -60,16 +60,16 @@ int sipc_semaphore_init(int id, int count)
   if (sem == MAP_FAILED)
     return -1;
   sem->count = count;
-  sprintf(buf, "/%d:sem%d:g", getpid(), id);
+  snprintf(buf,100, "/%d:sem%d:g", getpid(), id);
   sem_unlink(buf);
   sem->guard = sem_open(buf, O_CREAT, 0600, count);
   sem_unlink(buf);
-  sprintf(buf, "/%d:sem%d:s", getpid(), id);
+  snprintf(buf,100, "/%d:sem%d:s", getpid(), id);
   sem_unlink(buf);
   sem->sig = sem_open(buf, O_CREAT, 0600, count);
   sem_unlink(buf);
 #else
-  sprintf(buf, "/%d:sem%d", getpid(), id);
+  snprintf(buf,100, "/%d:sem%d", getpid(), id);
   sem_unlink(buf);
   sem = sem_open(buf, O_CREAT, 0600, count);
 #endif
@@ -105,7 +105,7 @@ int sipc_semaphore_acquire(int id)
 #endif
   sem_acquired[id]++;
   defer_shutdown--;
-  if (!defer_shutdown && do_shutdown) m2_end(1);
+  if (!defer_shutdown && do_shutdown) m2_end(-1);
   return 1;
 }
 
@@ -128,7 +128,7 @@ int sipc_semaphore_try_acquire(int id)
     sem_acquired[id]++;
   }
   defer_shutdown--;
-  if (!defer_shutdown && do_shutdown) m2_end(1);
+  if (!defer_shutdown && do_shutdown) m2_end(-1);
   return !trywait;
 }
 
@@ -146,7 +146,7 @@ int sipc_semaphore_release(int id)
 #endif
   sem_acquired[id]--;
   defer_shutdown--;
-  if (!defer_shutdown && do_shutdown) m2_end(1);
+  if (!defer_shutdown && do_shutdown) m2_end(-1);
   return 1;
 }
 
