@@ -8,6 +8,7 @@
 */
 
 #include "singularconfig.h"
+#include "omalloc/omalloc.h"
 #include "kernel/structs.h"
 
 #include "Singular/links/sing_dbm.h"
@@ -96,7 +97,7 @@ static inline si_link slCopy(si_link l)
   return l;
 }
 
-#include "omalloc/omalloc.h"
+
 static inline char* slString(si_link l)
 {
   if (l->name != NULL)
@@ -109,11 +110,11 @@ static inline char* slString(si_link l)
   }
 }
 
-extern omBin s_si_link_extension_bin;
-extern omBin sip_link_bin;
-extern omBin ip_link_bin;
+EXTERN_VAR omBin s_si_link_extension_bin;
+EXTERN_VAR omBin sip_link_bin;
+EXTERN_VAR omBin ip_link_bin;
 
-int slStatusSsiL(lists L, int timeout);
+int slStatusSsiL(lists L, int timeout, BOOLEAN* ignore=NULL);
 int ssiBatch(const char *host, const char * port);
 
 
@@ -126,6 +127,7 @@ typedef struct
 
 typedef link_struct* link_list;
 
-extern link_list ssiToBeClosed;
-extern volatile BOOLEAN ssiToBeClosed_inactive;
+EXTERN_VAR link_list ssiToBeClosed;
+EXTERN_VAR volatile BOOLEAN ssiToBeClosed_inactive;
+BOOLEAN ssiWrite2(si_link l, leftv res, leftv v);
 #endif // SILINK_H
