@@ -69,9 +69,11 @@ VAR link_list ssiToBeClosed=NULL;
 VAR volatile BOOLEAN ssiToBeClosed_inactive=TRUE;
 
 // forward declarations:
-static void ssiWritePoly_R(const ssiInfo *d, int typ, poly p, const ring r);
+static void ssiWritePoly_R(const ssiInfo *d, poly p, const ring r);
+static void ssiWritePoly_R_S(poly p, const ring r);
 static void ssiWriteIdeal_R(const ssiInfo *d, int typ,const ideal I, const ring r);
 static poly ssiReadPoly_R(const ssiInfo *D, const ring r);
+static poly ssiReadPoly_R_S(char **s, const ring r);
 static ideal ssiReadIdeal_R(const ssiInfo *d,const ring r);
 
 // the helper functions:
@@ -154,18 +156,28 @@ static void ssiCheckCurrRing(const ring r)
 void ssiWriteInt(const ssiInfo *d,const int i)
 {
   fprintf(d->f_write,"%d ",i);
-  //if (d->f_debug!=NULL) fprintf(d->f_debug,"int: %d ",i);
+}
+void ssiWriteInt_S(const int i)
+{
+  StringAppend("%d ",i);
 }
 
 static void ssiWriteString(const ssiInfo *d,const char *s)
 {
   fprintf(d->f_write,"%d %s ",(int)strlen(s),s);
-  //if (d->f_debug!=NULL) fprintf(d->f_debug,"stringi: %d \"%s\" ",strlen(s),s);
+}
+static void ssiWriteString_S(const char *s)
+{
+  StringAppend("%d %s ",(int)strlen(s),s);
 }
 
 static void ssiWriteBigInt(const ssiInfo *d, const number n)
 {
- n_WriteFd(n,d,coeffs_BIGINT);
+  n_WriteFd(n,d,coeffs_BIGINT);
+}
+static void ssiWriteBigInt_S(const number n)
+{
+  n_WriteFd_S(n,coeffs_BIGINT);
 }
 
 static void ssiWriteNumber_CF(const ssiInfo *d, const number n, const coeffs cf)
@@ -182,12 +194,12 @@ static void ssiWriteNumber_CF(const ssiInfo *d, const number n, const coeffs cf)
   if (getCoeffType(cf)==n_transExt)
   {
     fraction f=(fraction)n;
-    ssiWritePoly_R(d,POLY_CMD,NUM(f),cf->extRing);
-    ssiWritePoly_R(d,POLY_CMD,DEN(f),cf->extRing);
+    ssiWritePoly_R(d,NUM(f),cf->extRing);
+    ssiWritePoly_R(d,DEN(f),cf->extRing);
   }
   else if (getCoeffType(cf)==n_algExt)
   {
-    ssiWritePoly_R(d,POLY_CMD,(poly)n,cf->extRing);
+    ssiWritePoly_R(d,(poly)n,cf->extRing);
   }
   else if (cf->cfWriteFd!=NULL)
   {
@@ -196,6 +208,34 @@ static void ssiWriteNumber_CF(const ssiInfo *d, const number n, const coeffs cf)
   else WerrorS("coeff field not implemented");
 }
 
+static void ssiWriteNumber_CF_S(const number n, const coeffs cf)
+{
+  // syntax is as follows:
+  // case 1 Z/p:   3 <int>
+  // case 2 Q:     3 4 <int>
+  //        or     3 0 <mpz_t nominator> <mpz_t denominator>
+  //        or     3 1  dto.
+  //        or     3 3 <mpz_t nominator>
+  //        or     3 5 <mpz_t raw nom.> <mpz_t raw denom.>
+  //        or     3 6 <mpz_t raw nom.> <mpz_t raw denom.>
+  //        or     3 8 <mpz_t raw nom.>
+  if (getCoeffType(cf)==n_transExt)
+  {
+    fraction f=(fraction)n;
+    ssiWritePoly_R_S(NUM(f),cf->extRing);
+    ssiWritePoly_R_S(DEN(f),cf->extRing);
+  }
+  else if (getCoeffType(cf)==n_algExt)
+  {
+    ssiWritePoly_R_S((poly)n,cf->extRing);
+  }
+  else if (cf->cfWriteFd_S!=NULL)
+  {
+    n_WriteFd_S(n,cf);
+  }
+  else WerrorS("coeff field not implemented");
+}
+
 static void ssiWriteNumber(const ssiInfo *d, const number n)
 {
   ssiWriteNumber_CF(d,n,d->r->cf);
@@ -356,7 +396,7 @@ static void ssiWriteRing(ssiInfo *d,const ring r)
   }
   ssiWriteRing_R(d,r);
 }
-static void ssiWritePoly_R(const ssiInfo *d, int /*typ*/, poly p, const ring r)
+static void ssiWritePoly_R(const ssiInfo *d, poly p, const ring r)
 {
   fprintf(d->f_write,"%d ",pLength(p));//number of terms
 
@@ -373,12 +413,35 @@ static void ssiWritePoly_R(const ssiInfo *d, int /*typ*/, poly p, const ring r)
     pIter(p);
   }
 }
-
-static void ssiWritePoly(const ssiInfo *d, int typ, poly p)
+static void ssiWritePoly_R_S(poly p, const ring r)
 {
-  ssiWritePoly_R(d,typ,p,d->r);
+  StringAppend("%d ",pLength(p));//number of terms
+
+  while(p!=NULL)
+  {
+    ssiWriteNumber_CF_S(pGetCoeff(p),r->cf);
+    //nWrite(fich,pGetCoeff(p));
+    StringAppend("%ld ",p_GetComp(p,r));//component
+
+    for(int j=1;j<=rVar(r);j++)
+    {
+      StringAppend("%ld ",p_GetExp(p,j,r ));//x^j
+    }
+    pIter(p);
+  }
 }
 
+static void ssiWritePoly(const ssiInfo *d, poly p)
+{
+  ssiWritePoly_R(d,p,d->r);
+}
+
+char* ssiWritePoly_S(poly p, const ring r)
+{
+  StringSetS("");
+  ssiWritePoly_R_S(p,r);
+  return StringEndS();
+}
 static void ssiWriteIdeal_R(const ssiInfo *d, int typ,const ideal I, const ring R)
 {
    // syntax: 7 # of elements <poly 1> <poly2>.....(ideal,module,smatrix)
@@ -397,22 +460,56 @@ static void ssiWriteIdeal_R(const ssiInfo *d, int typ,const ideal I, const ring
      fprintf(d->f_write,"%d ",IDELEMS(I));
    }
 
-   int i;
-   int tt;
-   if ((typ==MODUL_CMD)||(typ==SMATRIX_CMD))
-     tt=VECTOR_CMD;
-   else
-     tt=POLY_CMD;
-
-   for(i=0;i<mn;i++)
+   for(int i=0;i<mn;i++)
    {
-     ssiWritePoly_R(d,tt,I->m[i],R);
+     ssiWritePoly_R(d,I->m[i],R);
+   }
+}
+static void ssiWriteIdeal_R_S(int typ,const ideal I, const ring R)
+{
+   // syntax: 7 # of elements <poly 1> <poly2>.....(ideal,module,smatrix)
+   // syntax: 8 <rows> <cols> <poly 1> <poly2>.....(matrix)
+   // syntax
+   matrix M=(matrix)I;
+   int mn;
+   if (typ==MATRIX_CMD)
+   {
+     mn=MATROWS(M)*MATCOLS(M);
+     StringAppend("%d %d ", MATROWS(M),MATCOLS(M));
+   }
+   else
+   {
+     mn=IDELEMS(I);
+     StringAppend("%d ",IDELEMS(I));
+   }
+
+   for(int i=0;i<mn;i++)
+   {
+     ssiWritePoly_R_S(I->m[i],R);
    }
 }
 void ssiWriteIdeal(const ssiInfo *d, int typ,const ideal I)
 {
   ssiWriteIdeal_R(d,typ,I,d->r);
 }
+char* ssiWriteIdeal_S(const ideal I, const ring R)
+{
+  StringSetS("");
+  ssiWriteIdeal_R_S(IDEAL_CMD,I,R);
+  return StringEndS();
+}
+char* ssiWriteMatrix_S(const matrix M, const ring R)
+{
+  StringSetS("");
+  ssiWriteIdeal_R_S(MATRIX_CMD,(ideal)M,R);
+  return StringEndS();
+}
+char* ssiWriteModule_S(const ideal M, const ring R) /* also for smatrix*/
+{
+  StringSetS("");
+  ssiWriteIdeal_R_S(MODUL_CMD,M,R);
+  return StringEndS();
+}
 
 static void ssiWriteCommand(si_link l, command D)
 {
@@ -436,6 +533,15 @@ static void ssiWriteProc(const ssiInfo *d,procinfov p)
   else
     ssiWriteString(d,"");
 }
+static void ssiWriteProc_S(procinfov p)
+{
+  if (p->data.s.body==NULL)
+    iiGetLibProcBuffer(p);
+  if (p->data.s.body!=NULL)
+    ssiWriteString_S(p->data.s.body);
+  else
+    ssiWriteString_S("");
+}
 
 static void ssiWriteList(si_link l,lists dd)
 {
@@ -448,6 +554,16 @@ static void ssiWriteList(si_link l,lists dd)
     ssiWrite(l,&(dd->m[i]));
   }
 }
+static void ssiWriteList_S(lists dd, const ring R)
+{
+  int Ll=dd->nr;
+  StringAppend("%d ",Ll+1);
+  int i;
+  for(i=0;i<=Ll;i++)
+  {
+    ssiWrite_S(&(dd->m[i]),R);
+  }
+}
 static void ssiWriteIntvec(const ssiInfo *d,intvec * v)
 {
   fprintf(d->f_write,"%d ",v->length());
@@ -457,6 +573,15 @@ static void ssiWriteIntvec(const ssiInfo *d,intvec * v)
     fprintf(d->f_write,"%d ",(*v)[i]);
   }
 }
+static void ssiWriteIntvec_S(intvec * v)
+{
+  StringAppend("%d ",v->length());
+  int i;
+  for(i=0;i<v->length();i++)
+  {
+    StringAppend("%d ",(*v)[i]);
+  }
+}
 static void ssiWriteIntmat(const ssiInfo *d,intvec * v)
 {
   fprintf(d->f_write,"%d %d ",v->rows(),v->cols());
@@ -466,6 +591,15 @@ static void ssiWriteIntmat(const ssiInfo *d,intvec * v)
     fprintf(d->f_write,"%d ",(*v)[i]);
   }
 }
+static void ssiWriteIntmat_S(intvec * v)
+{
+  StringAppend("%d %d ",v->rows(),v->cols());
+  int i;
+  for(i=0;i<v->length();i++)
+  {
+    StringAppend("%d ",(*v)[i]);
+  }
+}
 
 static void ssiWriteBigintmat(const ssiInfo *d,bigintmat * v)
 {
@@ -476,6 +610,15 @@ static void ssiWriteBigintmat(const ssiInfo *d,bigintmat * v)
     ssiWriteBigInt(d,(*v)[i]);
   }
 }
+static void ssiWriteBigintmat_S(bigintmat * v)
+{
+  StringAppend("%d %d ",v->rows(),v->cols());
+  int i;
+  for(i=0;i<v->length();i++)
+  {
+    ssiWriteBigInt_S((*v)[i]);
+  }
+}
 
 static void ssiWriteBigintvec(const ssiInfo *d,bigintmat * v)
 {
@@ -486,6 +629,15 @@ static void ssiWriteBigintvec(const ssiInfo *d,bigintmat * v)
     ssiWriteBigInt(d,(*v)[i]);
   }
 }
+static void ssiWriteBigintvec_S(bigintmat * v)
+{
+  StringAppend("%d ",v->cols());
+  int i;
+  for(i=0;i<v->length();i++)
+  {
+    ssiWriteBigInt_S((*v)[i]);
+  }
+}
 
 static char *ssiReadString(const ssiInfo *d)
 {
@@ -499,11 +651,26 @@ static char *ssiReadString(const ssiInfo *d)
   buf[l]='\0';
   return buf;
 }
+static char *ssiReadString_S(char** s)
+{
+  char *buf;
+  int l;
+  l=s_readint_S(s);
+  buf=(char*)omAlloc0(l+1);
+  (*s)++; /* skip ' '*/
+  for(int i=0;i<l;i++) { buf[i]=(**s); (*s)++; }
+  buf[l]='\0';
+  return buf;
+}
 
 int ssiReadInt(const ssiInfo *d)
 {
   return s_readint(d->f_read);
 }
+int ssiReadInt_S(char **s)
+{
+  return s_readint_S(s);
+}
 
 static number ssiReadNumber_CF(const ssiInfo *d, const coeffs cf)
 {
@@ -529,6 +696,30 @@ static number ssiReadNumber_CF(const ssiInfo *d, const coeffs cf)
   return NULL;
 }
 
+static number ssiReadNumber_CF_S(char **s, const coeffs cf)
+{
+  if (cf->cfReadFd_S!=ndReadFd_S)
+  {
+     return n_ReadFd_S(s,cf);
+  }
+  else if (getCoeffType(cf) == n_transExt)
+  {
+    // poly poly
+    fraction f=(fraction)n_Init(1,cf);
+    p_Delete(&NUM(f),cf->extRing);
+    NUM(f)=ssiReadPoly_R_S(s,cf->extRing);
+    DEN(f)=ssiReadPoly_R_S(s,cf->extRing);
+    return (number)f;
+  }
+  else if (getCoeffType(cf) == n_algExt)
+  {
+    // poly
+    return (number)ssiReadPoly_R_S(s,cf->extRing);
+  }
+  else WerrorS("coeffs not implemented in ssiReadNumber");
+  return NULL;
+}
+
 static number ssiReadBigInt(const ssiInfo *d)
 {
   number n=ssiReadNumber_CF(d,coeffs_BIGINT);
@@ -538,6 +729,15 @@ static number ssiReadBigInt(const ssiInfo *d)
   }
   return n;
 }
+static number ssiReadBigInt_S(char**s)
+{
+  number n=ssiReadNumber_CF_S(s,coeffs_BIGINT);
+  if ((SR_HDL(n) & SR_INT)==0)
+  {
+    if (n->s!=3) Werror("invalid sub type in bigint:%d",n->s);
+  }
+  return n;
+}
 
 static number ssiReadNumber(ssiInfo *d)
 {
@@ -745,11 +945,48 @@ static poly ssiReadPoly_R(const ssiInfo *d, const ring r)
  return ret;
 }
 
+static poly ssiReadPoly_R_S(char **s, const ring r)
+{
+// < # of terms> < term1> < .....
+  int n,i,l;
+  char* c=*s;
+  n=s_readint_S(&c); // # of terms
+  poly p;
+  poly ret=NULL;
+  poly prev=NULL;
+  for(l=0;l<n;l++) // read n terms
+  {
+// coef,comp.exp1,..exp N
+    p=p_Init(r,r->PolyBin);
+    number cf=ssiReadNumber_CF_S(&c,r->cf);
+    pSetCoeff0(p,cf);
+    int D;
+    D=s_readint_S(&c);
+    p_SetComp(p,D,r);
+    for(i=1;i<=rVar(r);i++)
+    {
+      D=s_readint_S(&c);
+      p_SetExp(p,i,D,r);
+    }
+    p_Setm(p,r);
+    p_Test(p,r);
+    if (ret==NULL) ret=p;
+    else           pNext(prev)=p;
+    prev=p;
+ }
+ *s=c;
+ return ret;
+}
+
 static poly ssiReadPoly(ssiInfo *d)
 {
   return ssiReadPoly_R(d,d->r);
 }
 
+poly ssiReadPoly_S(char *s, const ring r)
+{
+  return ssiReadPoly_R_S(&s,r);
+}
 static ideal ssiReadIdeal_R(const ssiInfo *d,const ring r)
 {
 // < # of terms> < term1> < .....
@@ -763,12 +1000,30 @@ static ideal ssiReadIdeal_R(const ssiInfo *d,const ring r)
   }
   return I;
 }
+static ideal ssiReadIdeal_R_S(char** s,const ring r)
+{
+// < # of terms> < term1> < .....
+  int n,i;
+  ideal I;
+  n=s_readint_S(s);
+  I=idInit(n,1); // will be fixed later for module/smatrix
+  for(i=0;i<IDELEMS(I);i++) // read n terms
+  {
+    I->m [i]=ssiReadPoly_R_S(s,r);
+  }
+  return I;
+}
 
 ideal ssiReadIdeal(ssiInfo *d)
 {
   return ssiReadIdeal_R(d,d->r);
 }
 
+ideal ssiReadIdeal_S(char *s, const ring R)
+{
+  return ssiReadIdeal_R_S(&s,R);
+}
+
 static matrix ssiReadMatrix(ssiInfo *d)
 {
   int n,m;
@@ -784,6 +1039,25 @@ static matrix ssiReadMatrix(ssiInfo *d)
     }
   return M;
 }
+static matrix ssiReadMatrix_R_S(char** s, const ring R)
+{
+  int n,m;
+  m=s_readint_S(s);
+  n=s_readint_S(s);
+  matrix M=mpNew(m,n);
+  poly p;
+  for(int i=1;i<=MATROWS(M);i++)
+    for(int j=1;j<=MATCOLS(M);j++)
+    {
+      p=ssiReadPoly_R_S(s,R);
+      MATELEM(M,i,j)=p;
+    }
+  return M;
+}
+matrix ssiReadMatrix_R_S(char* s, const ring R)
+{
+  return ssiReadMatrix_R_S(&s,R);
+}
 
 static command ssiReadCommand(si_link l)
 {
@@ -841,6 +1115,16 @@ static procinfov ssiReadProc(const ssiInfo *d)
   p->data.s.body=s;
   return p;
 }
+static procinfov ssiReadProc_S(char**s)
+{
+  char *st=ssiReadString_S(s);
+  procinfov p=(procinfov)omAlloc0Bin(procinfo_bin);
+  p->language=LANG_SINGULAR;
+  p->libname=omStrDup("");
+  p->procname=omStrDup("");
+  p->data.s.body=st;
+  return p;
+}
 static lists ssiReadList(si_link l)
 {
   ssiInfo *d=(ssiInfo*)l->data;
@@ -859,6 +1143,23 @@ static lists ssiReadList(si_link l)
   }
   return L;
 }
+static lists ssiReadList_S(char**s, const ring R)
+{
+  int nr;
+  nr=s_readint_S(s);
+  lists L=(lists)omAlloc0Bin(slists_bin);
+  L->Init(nr);
+
+  int i;
+  leftv v;
+  for(i=0;i<=L->nr;i++)
+  {
+    v=ssiRead1_S(s,R);
+    memcpy(&(L->m[i]),v,sizeof(*v));
+    omFreeBin(v,sleftv_bin);
+  }
+  return L;
+}
 static intvec* ssiReadIntvec(const ssiInfo *d)
 {
   int nr;
@@ -870,6 +1171,17 @@ static intvec* ssiReadIntvec(const ssiInfo *d)
   }
   return v;
 }
+static intvec* ssiReadIntvec_S(char**s)
+{
+  int nr;
+  nr=s_readint_S(s);
+  intvec *v=new intvec(nr);
+  for(int i=0;i<nr;i++)
+  {
+    (*v)[i]=s_readint_S(s);
+  }
+  return v;
+}
 static intvec* ssiReadIntmat(const ssiInfo *d)
 {
   int r,c;
@@ -882,6 +1194,18 @@ static intvec* ssiReadIntmat(const ssiInfo *d)
   }
   return v;
 }
+static intvec* ssiReadIntmat_S(char**s)
+{
+  int r,c;
+  r=s_readint_S(s);
+  c=s_readint_S(s);
+  intvec *v=new intvec(r,c,0);
+  for(int i=0;i<r*c;i++)
+  {
+    (*v)[i]=s_readint_S(s);
+  }
+  return v;
+}
 static bigintmat* ssiReadBigintmat(const ssiInfo *d)
 {
   int r,c;
@@ -894,6 +1218,18 @@ static bigintmat* ssiReadBigintmat(const ssiInfo *d)
   }
   return v;
 }
+static bigintmat* ssiReadBigintmat_S(char**s)
+{
+  int r,c;
+  r=s_readint_S(s);
+  c=s_readint_S(s);
+  bigintmat *v=new bigintmat(r,c,coeffs_BIGINT);
+  for(int i=0;i<r*c;i++)
+  {
+    (*v)[i]=ssiReadBigInt_S(s);
+  }
+  return v;
+}
 static bigintmat* ssiReadBigintvec(const ssiInfo *d)
 {
   int c;
@@ -905,10 +1241,20 @@ static bigintmat* ssiReadBigintvec(const ssiInfo *d)
   }
   return v;
 }
+static bigintmat* ssiReadBigintvec_S(char**s)
+{
+  int c;
+  c=s_readint_S(s);
+  bigintmat *v=new bigintmat(1,c,coeffs_BIGINT);
+  for(int i=0;i<c;i++)
+  {
+    (*v)[i]=ssiReadBigInt_S(s);
+  }
+  return v;
+}
 
 static void ssiReadBlackbox(leftv res, si_link l)
 {
-  ssiInfo *d=(ssiInfo*)l->data;
   leftv lv=ssiRead1(l);
   char *name=(char*)lv->data;
   omFreeBin(lv,sleftv_bin);
@@ -1001,13 +1347,24 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
   if (l!=NULL)
   {
     const char *mode;
-    ssiInfo *d=(ssiInfo*)omAlloc0(sizeof(ssiInfo));
     if (flag & SI_LINK_OPEN)
     {
-      if (l->mode[0] != '\0' && (strcmp(l->mode, "r") == 0))
+      if (strcmp(l->mode, "r") == 0)
         flag = SI_LINK_READ;
+      else if (strcmp(l->mode,"string")==0)
+      {
+        SI_LINK_SET_RW_OPEN_P(l);
+        return FALSE;
+      }
       else flag = SI_LINK_WRITE;
     }
+    if (((flag == SI_LINK_READ)
+      || (flag == SI_LINK_WRITE))
+    && (strcmp(l->mode,"string")==0))
+    {
+      SI_LINK_SET_RW_OPEN_P(l);
+      return FALSE;
+    }
 
     if (flag == SI_LINK_READ) mode = "r";
     else if (strcmp(l->mode, "w") == 0) mode = "w";
@@ -1019,14 +1376,24 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
 
     SI_LINK_SET_OPEN_P(l, flag);
     if(l->data!=NULL) omFreeSize(l->data,sizeof(ssiInfo));
-    l->data=d;
     omFreeBinAddr(l->mode);
     l->mode = omStrDup(mode);
 
+    ssiInfo *d=(ssiInfo*)omAlloc0(sizeof(ssiInfo));
+    l->data=d;
     if (l->name[0] == '\0')
     {
       if (strcmp(mode,"fork")==0)
       {
+        int cpus = (long) feOptValue(FE_OPT_CPUS);
+        if (cpus<1)
+        {
+          WerrorS("no sub-processes allowed");
+          l->flags=0;
+          l->data=NULL;
+          omFreeSize(d,sizeof(ssiInfo));
+          return TRUE;
+        }
         int pc[2];
         int cp[2];
         int err1=pipe(pc);
@@ -1034,6 +1401,9 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
         if (err1 || err2)
         {
           Werror("pipe failed with %d\n",errno);
+          l->flags=0;
+          l->data=NULL;
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
         link_list n=(link_list)omAlloc(sizeof(link_struct));
@@ -1051,6 +1421,10 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
         if (pid == -1)
         {
           WerrorS("could not fork");
+          l->flags=0;
+          l->data=NULL;
+          omFreeSize(d,sizeof(ssiInfo));
+          return TRUE;
         }
         if (pid==0) /*fork: child*/
         {
@@ -1103,8 +1477,8 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           }
           loop
           {
-            if (!SI_LINK_OPEN_P(l)) m2_end(0);
-            if(d->f_read->is_eof) m2_end(0);
+            if (!SI_LINK_OPEN_P(l)) m2_end(-1);
+            if(d->f_read->is_eof) m2_end(-1);
             leftv h=ssiRead1(l); /*contains an exit.... */
             if (feErrors != NULL && *feErrors != '\0')
             {
@@ -1135,7 +1509,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
         {
           Werror("fork failed (%d)",errno);
           l->data=NULL;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
       }
@@ -1150,7 +1524,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           WerrorS("ERROR opening socket");
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
         memset((char *) &serv_addr,0, sizeof(serv_addr));
@@ -1166,7 +1540,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
             WerrorS("ERROR on binding (no free port available?)");
             l->data=NULL;
             l->flags=0;
-            omFree(d);
+            omFreeSize(d,sizeof(ssiInfo));
             return TRUE;
           }
         }
@@ -1179,7 +1553,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           WerrorS("ERROR on accept");
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
         PrintS("client accepted\n");
@@ -1191,12 +1565,16 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
         si_close(sockfd);
       }
       // no ssi-Link on stdin or stdout
+      else if (strcmp(mode,"string")==0)
+      {
+        SI_LINK_SET_RW_OPEN_P(l);
+      }
       else
       {
         Werror("invalid mode >>%s<< for ssi",mode);
         l->data=NULL;
         l->flags=0;
-        omFree(d);
+        omFreeSize(d,sizeof(ssiInfo));
         return TRUE;
       }
     }
@@ -1214,7 +1592,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           WerrorS("ERROR opening socket");
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
         memset((char *) &serv_addr,0, sizeof(serv_addr));
@@ -1230,6 +1608,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
             WerrorS("ERROR on binding (no free port available?)");
             l->data=NULL;
             l->flags=0;
+            omFreeSize(d,sizeof(ssiInfo));
             return TRUE;
           }
         }
@@ -1244,7 +1623,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           WerrorS("ERROR: no host specified");
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           omFree(path);
           omFree(cli_host);
           return TRUE;
@@ -1275,7 +1654,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           Werror("ERROR running `%s` (%d)",ssh_command,re);
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
         omFree(ssh_command);
@@ -1287,7 +1666,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           WerrorS("ERROR on accept");
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
         //PrintS("client accepted\n");
@@ -1322,6 +1701,8 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           {
             WerrorS("ERROR opening socket");
             l->flags=0;
+            l->data=NULL;
+            omFreeSize(d,sizeof(ssiInfo));
             return TRUE;
           }
           server = gethostbyname(host);
@@ -1329,6 +1710,8 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           {
             WerrorS("ERROR, no such host");
             l->flags=0;
+            l->data=NULL;
+            omFreeSize(d,sizeof(ssiInfo));
             return TRUE;
           }
           memset((char *) &serv_addr, 0, sizeof(serv_addr));
@@ -1341,6 +1724,8 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
           {
             Werror("ERROR connecting(errno=%d)",errno);
             l->flags=0;
+            l->data=NULL;
+            omFreeSize(d,sizeof(ssiInfo));
             return TRUE;
           }
           //PrintS("connected\n");mflush();
@@ -1355,7 +1740,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
         {
           l->data=NULL;
           l->flags=0;
-          omFree(d);
+          omFreeSize(d,sizeof(ssiInfo));
           return TRUE;
         }
       }
@@ -1409,6 +1794,7 @@ BOOLEAN ssiOpen(si_link l, short flag, leftv u)
 }
 
 //**************************************************************************/
+#if 0
 static BOOLEAN ssiPrepClose(si_link l)
 {
   if (l!=NULL)
@@ -1427,6 +1813,7 @@ static BOOLEAN ssiPrepClose(si_link l)
   }
   return FALSE;
 }
+#endif
 
 BOOLEAN ssiClose(si_link l)
 {
@@ -1464,8 +1851,8 @@ BOOLEAN ssiClose(si_link l)
         {
           struct timespec t;
           struct timespec rem;
-          // wait 1 sec
-          for(int i=0;i<10;i++)
+          // wait 60 sec
+          for(int i=0;i<50;i++)
           {
             // wait till signal or 100ms:
             t.tv_sec=0;
@@ -1691,6 +2078,144 @@ no_ring: WerrorS("no ring");
   omFreeBin(res,sleftv_bin);
   return NULL;
 }
+leftv ssiRead1_S(char**s, const ring R)
+{
+  leftv res=(leftv)omAlloc0Bin(sleftv_bin);
+  int t=0;
+  t=s_readint_S(s);
+  switch(t)
+  {
+    case 1:res->rtyp=INT_CMD;
+           res->data=(char *)(long)ssiReadInt_S(s);
+           break;
+    case 2:res->rtyp=STRING_CMD;
+           res->data=(char *)ssiReadString_S(s);
+           break;
+    case 3:res->rtyp=NUMBER_CMD;
+           res->data=(char *)ssiReadNumber_CF_S(s,R->cf);
+           break;
+    case 4:res->rtyp=BIGINT_CMD;
+           res->data=(char *)ssiReadBigInt_S(s);
+           //Print("bigint\n");
+           break;
+    #if 0
+    case 15:
+    case 5:{
+           //Print("ring %d\n",t);
+             d->r=ssiReadRing(d);
+             if (errorreported) return NULL;
+             res->data=(char*)d->r;
+             if (d->r!=NULL) rIncRefCnt(d->r);
+             res->rtyp=RING_CMD;
+             if (t==15) // setring
+             {
+               if(ssiSetCurrRing(d->r)) { d->r=currRing; }
+               omFreeBin(res,sleftv_bin);
+               return ssiRead1(l);
+             }
+           }
+           break;
+    #endif
+    case 6:res->rtyp=POLY_CMD;
+           res->data=(char*)ssiReadPoly_R_S(s,R);
+           break;
+    case 7:res->rtyp=IDEAL_CMD;
+           res->data=(char*)ssiReadIdeal_R_S(s,R);
+           break;
+    case 8:res->rtyp=MATRIX_CMD;
+           res->data=(char*)ssiReadMatrix_R_S(s,R);
+           break;
+    case 9:res->rtyp=VECTOR_CMD;
+           res->data=(char*)ssiReadPoly_R_S(s,R);
+           break;
+    case 10:
+    case 22:if (t==22) res->rtyp=SMATRIX_CMD;
+           else        res->rtyp=MODUL_CMD;
+           {
+             int rk=s_readint_S(s);
+             ideal M=ssiReadIdeal_R_S(s,R);
+             M->rank=rk;
+             res->data=(char*)M;
+           }
+           break;
+    #if 0
+    case 11:
+           {
+             res->rtyp=COMMAND;
+             res->data=ssiReadCommand(l);
+             int nok=res->Eval();
+             if (nok) WerrorS("error in eval");
+             break;
+           }
+    #endif
+    case 12: /*DEF_CMD*/
+           {
+             res->rtyp=0;
+             res->name=(char *)ssiReadString_S(s);
+             int nok=res->Eval();
+             if (nok) WerrorS("error in name lookup");
+             break;
+           }
+    case 13: res->rtyp=PROC_CMD;
+             res->data=ssiReadProc_S(s);
+             break;
+    case 14: res->rtyp=LIST_CMD;
+             res->data=ssiReadList_S(s,R);
+             break;
+    case 16: res->rtyp=NONE; res->data=NULL;
+             break;
+    case 17: res->rtyp=INTVEC_CMD;
+             res->data=ssiReadIntvec_S(s);
+             break;
+    case 18: res->rtyp=INTMAT_CMD;
+             res->data=ssiReadIntmat_S(s);
+             break;
+    case 19: res->rtyp=BIGINTMAT_CMD;
+             res->data=ssiReadBigintmat_S(s);
+             break;
+    #if 0
+    case 20: ssiReadBlackbox(res,l);
+             break;
+    case 21: ssiReadAttrib(res,l);
+             break;
+    case 23: ssiReadRingProperties(l);
+             return ssiRead1(l);
+             break;
+    #endif
+    case 24: res->rtyp=BIGINTVEC_CMD;
+             res->data=ssiReadBigintvec_S(s);
+             break;
+    // ------------
+    case 98: // version
+             {
+                int n98_v,n98_m;
+                BITSET n98_o1,n98_o2;
+                n98_v=s_readint_S(s);
+                n98_m=s_readint_S(s);
+                n98_o1=s_readint_S(s);
+                n98_o2=s_readint_S(s);
+                Print("// version ssi-%d, MAX_TOK=%d\n",n98_v,n98_m);
+                si_opt_1=n98_o1;
+                si_opt_2=n98_o2;
+                omFreeBin(res,sleftv_bin);
+                return ssiRead1_S(s,R);
+             }
+    #if 0
+    case 99: omFreeBin(res,sleftv_bin); ssiClose(l); m2_end(-1);
+             break; /*to make compiler happy*/
+    #endif
+    case 0: res->rtyp=DEF_CMD;
+            **s='\0'; /* unkown char?*/
+            break;
+    default: Werror("not implemented (t:%d)",t);
+             omFreeBin(res,sleftv_bin);
+             res=NULL;
+             break;
+  }
+  while((**s!='\0') &&(**s<=' ')) (*s)++;
+  if (**s>' ') res->next=ssiRead1_S(s,R);
+  return res;
+}
 //**************************************************************************/
 static BOOLEAN ssiSetRing(si_link l, ring r, BOOLEAN send)
 {
@@ -1715,6 +2240,7 @@ BOOLEAN ssiWrite(si_link l, leftv data)
 {
   if(SI_LINK_W_OPEN_P(l)==0)
      if (slOpen(l,SI_LINK_OPEN|SI_LINK_WRITE,NULL)) return TRUE;
+  if (strcmp(l->mode,"string")==0) return TRUE;
   ssiInfo *d = (ssiInfo *)l->data;
   d->level++;
   //FILE *fich=d->f;
@@ -1774,7 +2300,7 @@ BOOLEAN ssiWrite(si_link l, leftv data)
                             if (d->level<=1) fputc('\n',d->f_write);
                           }
                           fputs("6 ",d->f_write);
-                          ssiWritePoly(d,tt,sBucketPeek(b));
+                          ssiWritePoly(d,sBucketPeek(b));
                           break;
                         }
           case POLY_CMD:
@@ -1787,7 +2313,7 @@ BOOLEAN ssiWrite(si_link l, leftv data)
                         }
                         if(tt==POLY_CMD) fputs("6 ",d->f_write);
                         else             fputs("9 ",d->f_write);
-                        ssiWritePoly(d,tt,(poly)dd);
+                        ssiWritePoly(d,(poly)dd);
                         break;
           case IDEAL_CMD:
           case MODUL_CMD:
@@ -1864,6 +2390,121 @@ BOOLEAN ssiWrite(si_link l, leftv data)
   d->level--;
   return FALSE;
 }
+void ssiWrite_S(leftv data,const ring R)
+{
+  while(data!=NULL)
+  {
+    int tt=data->Typ();
+    void *dd=data->Data();
+    switch(tt /*data->Typ()*/)
+    {
+      case 0: /*error*/
+      case NONE/* nothing*/:StringAppendS("16 ");
+           break;
+      case INT_CMD: StringAppendS("1 ");
+                          ssiWriteInt_S((int)(long)dd);
+                          break;
+      case STRING_CMD: StringAppendS("2 ");
+                             ssiWriteString_S((char *)dd);
+                             break;
+      case BIGINT_CMD:StringAppendS("4 ");
+                          ssiWriteBigInt_S((number)dd);
+                          break;
+      case NUMBER_CMD:
+        StringAppendS("3 ");
+        ssiWriteNumber_CF_S((number)dd,R->cf);
+        break;
+      #if 0
+      case RING_CMD:fputs("5 ",d->f_write);
+                          ssiWriteRing(d,(ring)dd);
+                          break;
+      #endif
+      case BUCKET_CMD:
+                          {
+                            sBucket_pt b=(sBucket_pt)dd;
+                            StringAppendS("6 ");
+                            ssiWritePoly_R_S(sBucketPeek(b),R);
+                            break;
+                          }
+      case POLY_CMD:
+      case VECTOR_CMD:
+        if(tt==POLY_CMD) StringAppendS("6 ");
+        else             StringAppendS("9 ");
+        ssiWritePoly_R_S((poly)dd,R);
+        break;
+      case IDEAL_CMD:
+      case MODUL_CMD:
+      case MATRIX_CMD:
+      case SMATRIX_CMD:
+        if(tt==IDEAL_CMD)       StringAppendS("7 ");
+        else if(tt==MATRIX_CMD) StringAppendS("8 ");
+        else /* tt==MODUL_CMD, SMATRIX_CMD*/
+        {
+          ideal M=(ideal)dd;
+          if (tt==MODUL_CMD)
+          {
+            StringAppendS("10 ");StringAppend("%d ",(int)M->rank);
+          }
+          else /*(tt==SMATRIX_CMD)*/
+          {
+            StringAppendS("22 ");StringAppend("%d ",(int)M->rank);
+          }
+        }
+        ssiWriteIdeal_R_S(tt,(ideal)dd,R);
+        break;
+      #if 0
+      case COMMAND:
+                     fputs("11 ",d->f_write);
+                     ssiWriteCommand(l,(command)dd);
+                     break;
+      #endif
+      case DEF_CMD: /* not evaluated stuff in quotes */
+                     StringAppendS("12 ");
+                     ssiWriteString_S(data->Name());
+                     break;
+      case PROC_CMD:
+                     StringAppendS("13 ");
+                     ssiWriteProc_S((procinfov)dd);
+                     break;
+      case LIST_CMD:
+                     StringAppendS("14 ");
+                     ssiWriteList_S((lists)dd,R);
+                     break;
+      case INTVEC_CMD:
+                     StringAppendS("17 ");
+                     ssiWriteIntvec_S((intvec *)dd);
+                     break;
+      case INTMAT_CMD:
+                     StringAppendS("18 ");
+                     ssiWriteIntmat_S((intvec *)dd);
+                     break;
+      case BIGINTMAT_CMD:
+                     StringAppendS("19 ");
+                     ssiWriteBigintmat_S((bigintmat *)dd);
+                     break;
+      case BIGINTVEC_CMD:
+                     StringAppendS("24 ");
+                     ssiWriteBigintvec_S((bigintmat *)dd);
+                     break;
+      default:
+              #if 0
+              if (tt>MAX_TOK)
+              {
+                blackbox *b=getBlackboxStuff(tt);
+                fputs("20 ",d->f_write);
+                b->blackbox_serialize(b,dd,l);
+              }
+              else
+              #endif
+              {
+                Werror("not implemented (t:%d, rtyp:%d)",tt, data->rtyp);
+                return;
+              }
+              break;
+    }
+    data=data->next;
+  }
+}
 
 BOOLEAN ssiGetDump(si_link l);
 BOOLEAN ssiDump(si_link l);
@@ -1874,7 +2515,7 @@ si_link_extension slInitSsiExtension(si_link_extension s)
   s->Close=ssiClose;
   s->Kill=ssiClose;
   s->Read=ssiRead1;
-  s->Read2=(slRead2Proc)NULL;
+  s->Read2=ssiRead2;
   s->Write=ssiWrite;
   s->Dump=ssiDump;
   s->GetDump=ssiGetDump;
@@ -1887,8 +2528,23 @@ si_link_extension slInitSsiExtension(si_link_extension s)
 
 const char* slStatusSsi(si_link l, const char* request)
 {
+  if (strcmp(l->mode,"string")==0)
+  {
+    if (strcmp(request, "read") == 0)
+    {
+      if (SI_LINK_R_OPEN_P(l)) return "yes";
+      else return "no";
+    }
+    if (strcmp(request, "write") == 0)
+    {
+      if (SI_LINK_W_OPEN_P(l)) return "yes";
+      else return "no";
+    }
+    return "inavlid";
+  }
   ssiInfo *d=(ssiInfo*)l->data;
-  if (d==NULL) return "not open";
+  if (d==NULL)
+    return "no";
   if (((strcmp(l->mode,"fork")==0)
   ||(strcmp(l->mode,"tcp")==0)
   ||(strcmp(l->mode,"connect")==0))
@@ -2312,10 +2968,10 @@ si_link ssiCommandLink()
 /*---------------------------------------------------------------------*/
 void sig_chld_hdl(int)
 {
-  pid_t kidpid;
-  int status;
 
 #if 0
+  pid_t kidpid;
+  int status;
   loop
   {
     kidpid = si_waitpid(-1, &status, WNOHANG);
@@ -2459,6 +3115,11 @@ static BOOLEAN ssiDumpIter(si_link l, idhdl h)
 }
 BOOLEAN ssiDump(si_link l)
 {
+  if (strcmp(l->mode,"string")==0)
+  {
+    WerrorS("no dump for ssi:string");
+    return TRUE;
+  }
   idhdl h = IDROOT, rh = currRingHdl;
   BOOLEAN status = ssiDumpIter(l, h);
 
@@ -2471,6 +3132,11 @@ BOOLEAN ssiDump(si_link l)
 }
 BOOLEAN ssiGetDump(si_link l)
 {
+  if (strcmp(l->mode,"string")==0)
+  {
+    WerrorS("no dump for ssi:string");
+    return TRUE;
+  }
   ssiInfo *d=(ssiInfo*)l->data;
   loop
   {
@@ -2509,6 +3175,30 @@ void singular_close_links()
   }
   ssiToBeClosed=NULL;
 }
+
+BOOLEAN ssiWrite2(si_link l, leftv res, leftv u)
+{
+  if((strcmp(l->mode,"string")==0)
+  &&(u->Typ()==STRING_CMD))
+  {
+    StringSetS("");
+    ssiWrite_S(u, currRing);
+    res->data=(void*)StringEndS();
+    res->rtyp=STRING_CMD;
+    return res->data==NULL;
+  }
+  return TRUE;
+}
+leftv ssiRead2(si_link l, leftv u)
+{
+  if((strcmp(l->mode,"string")==0)
+  &&(u->Typ()==STRING_CMD))
+  {
+    char *s=(char*)u->Data();
+    return ssiRead1_S(&s,currRing);
+  }
+ return NULL;
+}
 // ----------------------------------------------------------------
 // format
 // 1 int %d
