@@ -10,19 +10,6 @@
 
 #include "Singular/links/silink.h"
 
-typedef struct
-{
-  s_buff f_read;
-  FILE *f_write;
-  ring r;
-  pid_t pid; /* only valid for fork/tcp mode*/
-  int fd_read,fd_write; /* only valid for fork/tcp mode*/
-  char level;
-  char send_quit_at_exit;
-  char quit_sent;
-
-} ssiInfo;
-
 BOOLEAN ssiOpen(si_link l, short flag, leftv u);
 BOOLEAN ssiWrite(si_link l, leftv v);
 leftv ssiRead1(si_link l);
@@ -34,4 +21,13 @@ si_link_extension slInitSsiExtension(si_link_extension s);
 si_link ssiCommandLink();
 
 void sig_chld_hdl(int sig);
+int ssiReservePort(int clients);
+
+void singular_close_links();
+
+// for use in kstdhelper
+ideal ssiReadIdeal(ssiInfo *d);
+void ssiWriteIdeal(const ssiInfo *d, int typ,const ideal I);
+int ssiReadInt(const ssiInfo *d);
+void ssiWriteInt(const ssiInfo *d,const int i);
 #endif
