@@ -7,12 +7,12 @@
 * ABSTRACT - the mapping of polynomials to other rings
 */
 
-#include <kernel/mod2.h>
-#include <polys/matpol.h>
+#include "kernel/mod2.h"
+#include "polys/matpol.h"
 
-#include <kernel/structs.h>
-#include <kernel/ideals.h>
-#include <kernel/polys.h>
+#include "kernel/structs.h"
+#include "kernel/ideals.h"
+#include "kernel/polys.h"
 
 poly pSubstPoly(poly p, int var, poly image);
 poly pSubstPar(poly p, int par, poly image);
