@@ -562,7 +562,7 @@ const struct soptionStruct verboseStruct[]=
   {"warn",     Sy_bit(V_ALLWARN),   ~Sy_bit(V_ALLWARN)},
   {"intersectSyz",Sy_bit(V_INTERSECT_SYZ), ~Sy_bit(V_INTERSECT_SYZ)},
   {"intersectElim",Sy_bit(V_INTERSECT_ELIM), ~Sy_bit(V_INTERSECT_ELIM)},
-  {"no_try_HC",Sy_bit(V_NO_TRY_HC), ~Sy_bit(V_NO_TRY_HC)},
+  {"pure_gb",Sy_bit(V_PURE_GB), ~Sy_bit(V_PURE_GB)},
 /*special for "none" and also end marker for showOption:*/
   {"ne",         0,          0 }
 };
@@ -756,13 +756,10 @@ char * showOption()
 
 /* version strings */
 #ifdef HAVE_FLINT
-extern "C"
-{
 #ifndef __GMP_BITS_PER_MP_LIMB
 #define __GMP_BITS_PER_MP_LIMB GMP_LIMB_BITS
 #endif
 #include <flint/flint.h>
-}
 #endif
 
 #ifndef MAKE_DISTRIBUTION
@@ -1099,6 +1096,11 @@ extern "C" {
  */
 volatile BOOLEAN m2_end_called = FALSE;
 
+/* m2_end(0): close everything and return
+ * m2_end(1): close everything and exit(0)
+ * m2_end(i<0): close everything and _exit(0) (for children))
+ * m2_end(i>1): close everything and exit(i)
+ */
 void m2_end(int i)
 {
   if (!m2_end_called)
@@ -1138,10 +1140,6 @@ void m2_end(int i)
     }
 #endif   // HAVE_SIMPLEIPC
     monitor(NULL,0);
-#ifdef PAGE_TEST
-    mmEndStat();
-#endif
-    fe_reset_input_mode();
     if (ssiToBeClosed_inactive)
     {
       link_list hh=ssiToBeClosed;
@@ -1176,34 +1174,25 @@ void m2_end(int i)
         hh=ssiToBeClosed;
       }
     }
+#ifdef PAGE_TEST
+    mmEndStat();
+#endif
+    fe_reset_input_mode();
     if (!singular_in_batchmode)
     {
-      if (i<=0)
+      if (TEST_V_QUIET)
       {
-        //extern long all_farey;
-        //extern long farey_cnt;
-        //if (all_farey!=0L) printf("farey:%ld, cnt=%ld\n",all_farey,farey_cnt);
-        if (TEST_V_QUIET)
-        {
-          if (i==0)
-            printf("Auf Wiedersehen.\n");
-          else
-            printf("\n$Bye.\n");
-        }
-        //#ifdef sun
-        //  #ifndef __svr4__
-        //    _cleanup();
-        //    _exit(0);
-        //  #endif
-        //#endif
-        i=0;
+        if ((i==0)||(i==1))
+          printf("Auf Wiedersehen.\n");
       }
-      else
+      if (i>1)
       {
         printf("\nhalt %d\n",i);
       }
     }
-    exit(i);
+    if (i>1) exit(i);
+    else if (i==1) exit(0);
+    else if (i<0) _exit(0);
   }
 }
 }
@@ -1378,7 +1367,9 @@ void siInit(char *name)
     om_Opts.OutOfMemoryFunc = omSingOutOfMemoryFunc;
 #ifndef OM_NDEBUG
 #ifndef __OPTIMIZE__
+  #ifndef MAKE_DISTRUBTION
     om_Opts.ErrorHook = dErrorBreak;
+  #endif
 #else
     om_Opts.Keep = 0; /* !OM_NDEBUG, __OPTIMIZE__*/
 #endif
@@ -1391,6 +1382,27 @@ void siInit(char *name)
   extern void initPT();
   initPT();
 #endif
+ { // set cpus (in siInit), if SINGULAR_CPUS is set, set within the limits
+   char *env_cpu=getenv("SINGULAR_CPUS");
+   if (env_cpu!=NULL)
+   {
+      int cpu_n,cpus;
+      #ifdef _SC_NPROCESSORS_ONLN
+      if ((cpu_n=sysconf(_SC_NPROCESSORS_ONLN))>cpus) cpus=cpu_n;
+      #elif defined(_SC_NPROCESSORS_CONF)
+      if ((cpu_n=sysconf(_SC_NPROCESSORS_CONF))>cpus) cpus=cpu_n;
+      #endif
+      #ifdef HAVE_SIMPLEIPC
+      if (cpus>SIPC_MAX_SEMAPHORES) cpus=SIPC_MAX_SEMAPHORES;
+      #endif
+
+     int t=atoi(env_cpu);
+     if ((t>=0)&&(t<cpus)) cpus=t;
+     feSetOptValue(FE_OPT_CPUS, cpus);
+     // how many threads ? -----------------------------------------------------
+     feSetOptValue(FE_OPT_THREADS, cpus);
+   }
+ }
 // options ---------------------------------------------------------------
   si_opt_1=0;
 // interpreter tables etc.: -----------------------------------------------
@@ -1431,13 +1443,15 @@ void siInit(char *name)
 #endif
 
 // random generator: -----------------------------------------------
-  int t=startTimer();
-  if (t==0) t=1;
-  initRTimer();
-  siSeed=t;
-  factoryseed(t);
-  siRandomStart=t;
-  feOptSpec[FE_OPT_RANDOM].value = (void*) ((long)siRandomStart);
+  {
+    int t=startTimer();
+    if (t==0) t=1;
+    initRTimer();
+    siSeed=t;
+    factoryseed(t);
+    siRandomStart=t;
+    feOptSpec[FE_OPT_RANDOM].value = (void*) ((long)siRandomStart);
+  }
 
 // ressource table: ----------------------------------------------------
   // Don't worry: ifdef OM_NDEBUG, then all these calls are undef'ed
@@ -1447,20 +1461,6 @@ void siInit(char *name)
 // singular links: --------------------------------------------------
   slStandardInit();
   myynest=0;
-// how many processes ? -----------------------------------------------------
-  int cpus=2;
-  int cpu_n;
-  #ifdef _SC_NPROCESSORS_ONLN
-  if ((cpu_n=sysconf(_SC_NPROCESSORS_ONLN))>cpus) cpus=cpu_n;
-  #elif defined(_SC_NPROCESSORS_CONF)
-  if ((cpu_n=sysconf(_SC_NPROCESSORS_CONF))>cpus) cpus=cpu_n;
-  #endif
-  #ifdef HAVE_VSPACE
-  if (cpus>vspace::internals::MAX_PROCESS) cpus=vspace::internals::MAX_PROCESS;
-  #endif
-  feSetOptValue(FE_OPT_CPUS, cpus);
-// how many threads ? -----------------------------------------------------
-  feSetOptValue(FE_OPT_THREADS, cpus);
 
 // default coeffs
   {
