@@ -119,7 +119,7 @@ void sdb_edit(procinfo *pi)
   if (pi->language!= LANG_SINGULAR)
   {
     Print("cannot edit type %d\n",pi->language);
-    close(f);
+    si_close(f);
   }
   else
   {
@@ -136,15 +136,22 @@ void sdb_edit(procinfo *pi)
       if (pi->data.s.body==NULL)
       {
         PrintS("cannot get the procedure body\n");
-        close(f);
+        si_close(f);
         si_unlink(filename);
         omFree(filename);
         return;
       }
     }
 
-    write(f,pi->data.s.body,strlen(pi->data.s.body));
-    close(f);
+    ssize_t res=write(f,pi->data.s.body,strlen(pi->data.s.body));
+    si_close(f);
+    if (res==-1)
+    {
+      PrintS("cannot write the procedure body\n");
+      si_unlink(filename);
+      omFree(filename);
+      return;
+    }
 
     int pid=fork();
     if (pid!=0)
@@ -163,7 +170,11 @@ void sdb_edit(procinfo *pi)
         size_t len=strlen(editor)+strlen(filename)+2;
         char *p=(char *)omAlloc(len);
         snprintf(p,len,"%s %s",editor,filename);
-        system(p);
+        int res=system(p);
+	if (res<0)
+	{
+          Print("cannot call `%s`\n",editor);
+	}
       }
       exit(0);
     }
