@@ -17,7 +17,7 @@ typedef union
   sleftv    lv;
 } MYYSTYPE;
 #define YYSTYPE MYYSTYPE
-extern YYSTYPE  yylval;
+EXTERN_VAR YYSTYPE  yylval;
 
 int yylex(MYYSTYPE *l);
 
