@@ -110,6 +110,9 @@ void sleftv::Print(leftv store, int spaces)
         case BIGINTMAT_CMD:
           ((bigintmat *)d)->pprint(colmax);
           break;
+        case BIGINTVEC_CMD:
+          ((bigintmat *)d)->pprint(4096); // allow longer bigintvec
+          break;
         case BUCKET_CMD:
           {
             sBucket_pt b=(sBucket_pt)d;
@@ -445,6 +448,7 @@ static inline void * s_internalCopy(const int t,  void *d)
     case CMATRIX_CMD: // like BIGINTMAT
 #endif
     case BIGINTMAT_CMD:
+    case BIGINTVEC_CMD:
       return (void*)bimCopy((bigintmat *)d);
     case BUCKET_CMD:
       return (void*)sBucketCopy((sBucket_pt)d);
@@ -545,6 +549,7 @@ void s_internalDelete(const int t,  void *d, const ring r)
     case CMATRIX_CMD: //like BIGINTMAT
 #endif
     case BIGINTMAT_CMD:
+    case BIGINTVEC_CMD:
     {
       bigintmat *v=(bigintmat*)d;
       delete v;
@@ -567,8 +572,7 @@ void s_internalDelete(const int t,  void *d, const ring r)
     {
       map m=(map)d;
       omFreeBinAddr((ADDRESS)m->preimage);
-      m->preimage=NULL;
-      /* no break: continue as IDEAL*/
+      m->preimage=NULL; /* no break: continue as IDEAL*/
     }
     case SMATRIX_CMD:
     case MATRIX_CMD:
@@ -784,13 +788,23 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
         case INT_CMD:
           if (typed)
           {
-            s=(char *)omAlloc(MAX_INT_LEN+7);
-            sprintf(s,"int(%d)",(int)(long)d);
+            #if SIZEOF_LONG==8
+            const size_t len=MAX_INT_LEN+17;
+            #else
+            const size_t len=MAX_INT_LEN+7;
+            #endif
+            s=(char*)omAlloc(len);
+            snprintf(s,len,"int(%ld)",(long)d);
           }
           else
           {
-            s=(char *)omAlloc(MAX_INT_LEN+2);
-            sprintf(s,"%d",(int)(long)d);
+            #if SIZEOF_LONG==8
+            const size_t len=MAX_INT_LEN+12;
+            #else
+            const size_t len=MAX_INT_LEN+2;
+            #endif
+            s=(char*)omAlloc(len);
+            snprintf(s,len,"%ld",(long)d);
           }
           return s;
 
@@ -802,8 +816,9 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
           }
           if (typed)
           {
-            s = (char*) omAlloc(strlen((char*) d) + 3);
-            sprintf(s,"\"%s\"", (char*) d);
+            size_t len=strlen((char*) d) + 3;
+            s = (char*) omAlloc(len);
+            snprintf(s,len,"\"%s\"", (char*) d);
             return s;
           }
           else
@@ -816,8 +831,9 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
           if (typed)
           {
             char* ps = pString((poly) d);
-            s = (char*) omAlloc(strlen(ps) + 10);
-            sprintf(s,"%s(%s)", (t /*Typ()*/ == POLY_CMD ? "poly" : "vector"), ps);
+            size_t len=strlen(ps) + 10;
+            s = (char*) omAlloc(len);
+            snprintf(s,len,"%s(%s)", (t /*Typ()*/ == POLY_CMD ? "poly" : "vector"), ps);
             omFree(ps);
             return s;
           }
@@ -863,8 +879,9 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
           s= iiStringMatrix((matrix)d,dim, currRing);
           if (typed)
           {
-            char* ns = (char*) omAlloc(strlen(s) + 40);
-            sprintf(ns, "matrix(ideal(%s),%d,%d)", s,
+            size_t len=strlen(s) + 40;
+            char* ns = (char*) omAlloc(len);
+            snprintf(ns,len, "matrix(ideal(%s),%d,%d)", s,
                     ((ideal) d)->nrows, ((ideal) d)->ncols);
             omCheckAddr(ns);
             return ns;
@@ -881,11 +898,12 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
           s= iiStringMatrix((matrix)d,dim, currRing);
           if (typed)
           {
-            char* ns = (char*) omAlloc(strlen(s) + 10);
+            size_t len=strlen(s) + 10;
+            char* ns = (char*) omAlloc(len);
             if ((t/*Typ()*/==IDEAL_CMD)||(t==MAP_CMD))
-              sprintf(ns, "ideal(%s)", s);
+              snprintf(ns,len, "ideal(%s)", s);
             else /*MODUL_CMD, SMATRIX_CMD */
-              sprintf(ns, "module(%s)", s);
+              snprintf(ns,len, "module(%s)", s);
             omFree(s);
             omCheckAddr(ns);
             return ns;
@@ -902,13 +920,15 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
             char* ns;
             if (t/*Typ()*/ == INTMAT_CMD)
             {
-              ns = (char*) omAlloc(strlen(s) + 40);
-              sprintf(ns, "intmat(intvec(%s),%d,%d)", s, v->rows(), v->cols());
+              size_t len=strlen(s) + 40;
+              ns = (char*) omAlloc(len);
+              snprintf(ns,len, "intmat(intvec(%s),%d,%d)", s, v->rows(), v->cols());
             }
             else
             {
-              ns = (char*) omAlloc(strlen(s) + 10);
-              sprintf(ns, "intvec(%s)", s);
+              size_t len=strlen(s) + 10;
+              ns = (char*) omAlloc(len);
+              snprintf(ns,len, "intvec(%s)", s);
             }
             omCheckAddr(ns);
             omFree(s);
@@ -923,9 +943,23 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
           s = bim->String();
           if (typed)
           {
-            char* ns = (char*) omAlloc0(strlen(s) + 40);
-            sprintf(ns, "bigintmat(bigintvec(%s),%d,%d)", s, bim->rows(), bim->cols());
-            omCheckAddr(ns);
+            size_t len=strlen(s) + 40;
+            char* ns = (char*) omAlloc(len);
+            snprintf(ns,len, "bigintmat(bigintvec(%s),%d,%d)", s, bim->rows(), bim->cols());
+            return ns;
+          }
+          else
+            return omStrDup(s);
+        }
+        case BIGINTVEC_CMD:
+        {
+          bigintmat *bim=(bigintmat*)d;
+          s = bim->String();
+          if (typed)
+          {
+            size_t len=strlen(s) + 40;
+            char* ns = (char*) omAlloc(len);
+            snprintf(ns,len, "bigintvec(%s)", s);
             return ns;
           }
           else
@@ -943,13 +977,15 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
             {
               char* id = iiStringMatrix((matrix) ((ring) d)->qideal, dim,
                               currRing);
-              ns = (char*) omAlloc(strlen(s) + strlen(id) + 20);
-              sprintf(ns, "\"%s\";%sideal(%s)", s,(dim == 2 ? "\n" : " "), id);
+              size_t len=strlen(s) + strlen(id) + 20;
+              ns = (char*) omAlloc(len);
+              snprintf(ns,len, "\"%s\";%sideal(%s)", s,(dim == 2 ? "\n" : " "), id);
             }
             else
             {
-              ns = (char*) omAlloc(strlen(s) + 4);
-              sprintf(ns, "\"%s\"", s);
+              size_t len=strlen(s) + 4;
+              ns = (char*) omAlloc(len);
+              snprintf(ns,len, "\"%s\"", s);
             }
             omFree(s);
             omCheckAddr(ns);
@@ -973,9 +1009,9 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
             s = (char *)"";
           if (typed)
           {
-            char* ns = (char*) omAlloc(strlen(s) + 4);
-            sprintf(ns, "\"%s\"", s);
-            omCheckAddr(ns);
+            size_t len=strlen(s) + 4;
+            char* ns = (char*) omAlloc(len);
+            snprintf(ns,len, "\"%s\"", s);
             return ns;
           }
           return omStrDup(s);
@@ -985,8 +1021,9 @@ char *  sleftv::String(void *d, BOOLEAN typed, int dim)
           s = slString((si_link) d);
           if (typed)
           {
-            char* ns = (char*) omAlloc(strlen(s) + 10);
-            sprintf(ns, "link(\"%s\")", s);
+            size_t len=strlen(s) + 10;
+            char* ns = (char*) omAlloc(len);
+            snprintf(ns,len, "link(\"%s\")", s);
             omFreeBinAddr(s);
             omCheckAddr(ns);
             return ns;
@@ -1066,6 +1103,7 @@ int  sleftv::Typ()
     case INTMAT_CMD:
       r=INT_CMD;
       break;
+    case BIGINTVEC_CMD:
     case BIGINTMAT_CMD:
       r=BIGINT_CMD;
       break;
@@ -1251,6 +1289,19 @@ void * sleftv::Data()
         r=(char *)(long)(IMATELEM((*iv),index,e->next->start));
       break;
     }
+    case BIGINTVEC_CMD:
+    {
+      bigintmat *m=(bigintmat *)d;
+      if ((index<1)
+         ||(index>m->cols()))
+      {
+        if (!errorreported)
+          Werror("wrong range[%d] in bigintvec %s(%d)",index,this->Name(),m->cols());
+      }
+      else
+        r=(char *)(BIMATELEM((*m),1,index));
+      break;
+    }
     case BIGINTMAT_CMD:
     {
       bigintmat *m=(bigintmat *)d;
@@ -1567,7 +1618,8 @@ void syMake(leftv v,const char * id, package pa)
   * 3) existing identifier, local
   * 4) ringvar, ringpar, local ring
   * 5) existing identifier, global
-  * 6) monom (resp. number), local ring: consisting of:
+  * 6a) int/bigint
+  * 6b) monom (resp. number), local ring: consisting of:
   * 6') ringvar,  ringpar,global ring
   * 6'') monom (resp. number), local ring
   * 7) monom (resp. number), non-local ring
@@ -1595,91 +1647,131 @@ void syMake(leftv v,const char * id, package pa)
   if (siq<=0)
 #endif
   {
-    if (strcmp(id,"basering")==0)
+    if (id[0]=='#')
     {
-      if (currRingHdl!=NULL)
+      h=ggetid(id);
+      /* 3) existing identifier, local */
+      if ((h!=NULL) && (IDLEV(h)==myynest))
       {
-        if (id!=IDID(currRingHdl)) omFreeBinAddr((ADDRESS)id);
-        h=currRingHdl;
+        if (id!=IDID(h)) omFreeBinAddr((ADDRESS)id); /*assume strlen(id) <1000 */
         goto id_found;
       }
+    }
+    else if ((id[0]!='-')&&(id[0]>='@' /* letters, _ */))
+    {
+      if (strcmp(id,"basering")==0)
+      {
+        if (currRingHdl!=NULL)
+        {
+          if (id!=IDID(currRingHdl)) omFreeBinAddr((ADDRESS)id);
+          h=currRingHdl;
+          goto id_found;
+        }
+        else
+        {
+          v->name = id;
+          return; /* undefined */
+        }
+      }
+      else if (strcmp(id,"Current")==0)
+      {
+        if (currPackHdl!=NULL)
+        {
+          omFreeBinAddr((ADDRESS)id);
+          h=currPackHdl;
+          goto id_found;
+        }
+        else
+        {
+          v->name = id;
+          return; /* undefined */
+        }
+      }
+      if(v->req_packhdl!=currPack)
+      {
+        h=v->req_packhdl->idroot->get(id,myynest);
+      }
       else
       {
-        v->name = id;
-        return; /* undefined */
+        h=ggetid(id);
       }
-    }
-    else if (strcmp(id,"Current")==0)
-    {
-      if (currPackHdl!=NULL)
+      /* 3) existing identifier, local */
+      if ((h!=NULL) && (IDLEV(h)==myynest))
       {
-        omFreeBinAddr((ADDRESS)id);
-        h=currPackHdl;
+        if (id!=IDID(h)) omFreeBinAddr((ADDRESS)id); /*assume strlen(id) <1000 */
         goto id_found;
       }
-      else
+      if (yyInRingConstruction)
       {
-        v->name = id;
-        return; /* undefined */
+        currRingHdl=NULL;
+      }
+      /* 4. local ring: ringvar */
+      if ((currRingHdl!=NULL) && (IDLEV(currRingHdl)==myynest)
+      /*&& (!yyInRingConstruction)*/)
+      {
+        int vnr;
+        if ((vnr=r_IsRingVar(id, currRing->names,currRing->N))>=0)
+        {
+          poly p=pOne();
+          pSetExp(p,vnr+1,1);
+          pSetm(p);
+          v->data = (void *)p;
+          v->name = id;
+          v->rtyp = POLY_CMD;
+          return;
+        }
+        if((n_NumberOfParameters(currRing->cf)>0)
+        &&((vnr=r_IsRingVar(id, (char**)n_ParameterNames(currRing->cf),
+                                n_NumberOfParameters(currRing->cf))>=0)))
+        {
+          BOOLEAN ok=FALSE;
+          poly p = pmInit(id,ok);
+          if (ok && (p!=NULL))
+          {
+            v->data = pGetCoeff(p);
+            pGetCoeff(p)=NULL;
+            pLmFree(p);
+            v->rtyp = NUMBER_CMD;
+            v->name = id;
+            return;
+          }
+        }
+      }
+      /* 5. existing identifier, global */
+      if (h!=NULL)
+      {
+        if (id!=IDID(h)) omFreeBinAddr((ADDRESS)id);  /*assume strlen(id) <1000 */
+        goto id_found;
       }
-    }
-    if(v->req_packhdl!=currPack)
-    {
-      h=v->req_packhdl->idroot->get(id,myynest);
     }
     else
     {
-      h=ggetid(id);
-    }
-    /* 3) existing identifier, local */
-    if ((h!=NULL) && (IDLEV(h)==myynest))
-    {
-      if (id!=IDID(h)) omFreeBinAddr((ADDRESS)id); /*assume strlen(id) <1000 */
-      goto id_found;
-    }
-    if (yyInRingConstruction)
-    {
-      currRingHdl=NULL;
-    }
-    /* 4. local ring: ringvar */
-    if ((currRingHdl!=NULL) && (IDLEV(currRingHdl)==myynest)
-    /*&& (!yyInRingConstruction)*/)
-    {
-      int vnr;
-      if ((vnr=r_IsRingVar(id, currRing->names,currRing->N))>=0)
+      /* 6a: int/bigint */
+      int i=0;
+      if (id[0]=='-') { i=1; }
+      while(isdigit(id[i])) i++;
+      if (id[i]=='\0')
       {
-        poly p=pOne();
-        pSetExp(p,vnr+1,1);
-        pSetm(p);
-        v->data = (void *)p;
-        v->name = id;
-        v->rtyp = POLY_CMD;
+        int j=atoi(id);
+        char tmp[MAX_INT_LEN+5];
+        snprintf(tmp,MAX_INT_LEN+5,"%d",j);
+        if (strcmp(tmp,id)!=0)
+        {
+          number n;
+          n_Read(id,&n,coeffs_BIGINT);
+          v->rtyp=BIGINT_CMD;
+          v->data = n;
+        }
+        else
+        {
+          v->data=(void*)(long)j;
+          v->rtyp=INT_CMD;
+        }
+        omFreeBinAddr((ADDRESS)id);
         return;
       }
-      if((n_NumberOfParameters(currRing->cf)>0)
-      &&((vnr=r_IsRingVar(id, (char**)n_ParameterNames(currRing->cf),
-                              n_NumberOfParameters(currRing->cf))>=0)))
-      {
-        BOOLEAN ok=FALSE;
-        poly p = pmInit(id,ok);
-        if (ok && (p!=NULL))
-        {
-          v->data = pGetCoeff(p);
-          pGetCoeff(p)=NULL;
-          pLmFree(p);
-          v->rtyp = NUMBER_CMD;
-          v->name = id;
-          return;
-        }
-      }
     }
-    /* 5. existing identifier, global */
-    if (h!=NULL)
-    {
-      if (id!=IDID(h)) omFreeBinAddr((ADDRESS)id);  /*assume strlen(id) <1000 */
-      goto id_found;
-    }
-    /* 6. local ring: number/poly */
+    /* 6b local ring: number/poly */
     if ((currRingHdl!=NULL) && (IDLEV(currRingHdl)==myynest))
     {
       BOOLEAN ok=FALSE;
