@@ -16,9 +16,14 @@
 #include "imm.h"
 #include "cf_primes.h"
 #include "cf_util.h"
+#include "int_pp.h"
 
-static int theCharacteristic = 0;
-static int theDegree = 1;
+#ifdef HAVE_FLINT
+#include "FLINTconvert.h" // for __FLINT_RELEASE
+#endif
+
+STATIC_VAR int theCharacteristic = 0;
+STATIC_VAR int theDegree = 1;
 
 void setCharacteristic( int c )
 {
@@ -32,13 +37,27 @@ void setCharacteristic( int c )
     {
         theDegree = 1;
         CFFactory::settype( FiniteFieldDomain );
-        theCharacteristic = c;
         ff_big = c > cf_getSmallPrime( cf_getNumSmallPrimes()-1 );
-        if (c > 536870909) factoryError("characteristic is too large(max is 2^29)");
-        ff_setprime( c );
+        if (c!=theCharacteristic)
+        {
+          if (c > 536870909) factoryError("characteristic is too large(max is 2^29)");
+          ff_setprime( c );
+        }
+        theCharacteristic = c;
     }
 }
 
+#if !defined(HAVE_NTL)
+void setCharacteristic( int c, int n )
+{
+    ASSERT( c > 1 && n > 0, "illegal characteristic" );
+    setCharacteristic( c );
+    InternalPrimePower::setPrimePower( c, n );
+    CFFactory::settype( PrimePowerDomain );
+}
+#endif
+
+
 void setCharacteristic( int c, int n, char name )
 {
     ASSERT( c != 0 && n > 1, "illegal GF(q)" );
