@@ -1,7 +1,7 @@
 #ifndef CF_ROOTS_H
 #define CF_ROOTS_H
 
-int* FACTORY_PUBLIC Zp_roots (const CanonicalForm f);
+int* Zp_roots (const CanonicalForm f);
 
 
 #endif
