@@ -3,15 +3,15 @@
 #ifndef INCL_CF_UTIL_H
 #define INCL_CF_UTIL_H
 
-// #include "config.h"
+#include "globaldefs.h"
 
 int ilog2 (int a);
 
 /*BEGINPUBLIC*/
 int igcd (int a, int b);
-int ipower ( int b, int n );
+int FACTORY_PUBLIC ipower ( int b, int n );
 void factoryError_intern(const char *s);
-extern void (*factoryError)(const char *s);
+EXTERN_VAR void (*factoryError)(const char *s);
 /*ENDPUBLIC*/
 
 
