@@ -21,10 +21,10 @@
 #include <strstream>
 #include <string>
 #else
-#include <iostream.h>
-#include <fstream.h>
-#include <strstream.h>
-#include <string.h>
+#include <iostream>
+#include <fstream>
+#include <strstream>
+#include <string>
 #endif
 
 
@@ -37,6 +37,7 @@
 
 using namespace std;
 
+int gf_tab_numdigits62 ( int q );
 /**
  *
  * constants.
@@ -56,7 +57,7 @@ const int primes_len = 54;
  * primes, primes_len:
  *   used to step through possible extensions
 **/
-static unsigned short primes [] =
+STATIC_VAR unsigned short primes [] =
 {
       2,   3,   5,   7,  11,  13,  17,  19,
      23,  29,  31,  37,  41,  43,  47,  53,
