@@ -20,15 +20,15 @@
 //TODO make these functions members of CanonicalForm?
 /*BEGINPUBLIC*/
 
-void gmp_numerator ( const CanonicalForm & f, mpz_ptr result );
+void FACTORY_PUBLIC gmp_numerator ( const CanonicalForm & f, mpz_ptr result );
 
-void gmp_denominator ( const CanonicalForm & f, mpz_ptr result );
+void FACTORY_PUBLIC gmp_denominator ( const CanonicalForm & f, mpz_ptr result );
 
 int gf_value (const CanonicalForm & f );
 
-CanonicalForm make_cf ( const mpz_ptr n );
+CanonicalForm FACTORY_PUBLIC make_cf ( const mpz_ptr n );
 
-CanonicalForm make_cf ( const mpz_ptr n, const mpz_ptr d, bool normalize );
+CanonicalForm FACTORY_PUBLIC make_cf ( const mpz_ptr n, const mpz_ptr d, bool normalize );
 
 CanonicalForm make_cf_from_gf ( const int z );
 
