@@ -22,16 +22,17 @@
 
 #include "kernel/structs.h"
 #include "kernel/GBEngine/kstd1.h"   /* for s_poly_proc_t */
+#include "coeffs/bigintmat.h"   /* for s_poly_proc_t */
 
 // define if tailrings should be used
 #define HAVE_TAIL_RING
 
 #define setmax 128
-#define setmaxL ((4096-12)/sizeof(LObject))
-#define setmaxLinc ((4096)/sizeof(LObject))
+#define setmaxL ((int)((4096-12)/sizeof(LObject)))
+#define setmaxLinc ((int)((4096)/sizeof(LObject)))
 
-#define setmaxT ((4096-12)/sizeof(TObject))
-#define setmaxTinc ((4096)/sizeof(TObject))
+#define setmaxT ((int)((4096-12)/sizeof(TObject)))
+#define setmaxTinc ((int)((4096)/sizeof(TObject)))
 
 #define RED_CANONICALIZE 200
 #define REDNF_CANONICALIZE 60
@@ -355,7 +356,6 @@ public:
   int lastAxis;
   int newIdeal;
   int minim;
-  #ifdef HAVE_RINGS
   bool sigdrop; //This is used to check sigdrop in sba over Z
   int nrsyzcrit; // counts how many pairs are deleted by SyzCrit
   int nrrewcrit; // counts how many pairs are deleted by FaugereRewCrit
@@ -363,7 +363,6 @@ public:
                  // add directly sbaEnterS elements into S
   int blockred;  // counter for blocked reductions in redSig
   int blockredmax;
-  #endif
   #ifdef HAVE_SHIFTBBA
   int cv; // in shift bases: counting V criterion
   /*BOOLEAN*/ char rightGB;
@@ -487,14 +486,12 @@ int posInL110 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
 KINLINE poly redtailBba (poly p,int end_pos,kStrategy strat,BOOLEAN normalize=FALSE);
 KINLINE poly redtailBbaBound (poly p,int end_pos,kStrategy strat,int bound,BOOLEAN normalize=FALSE);
-#ifdef HAVE_RINGS
 KINLINE poly redtailBba_Ring (poly p,int end_pos,kStrategy strat);
 KINLINE poly redtailBba_Z (poly p,int end_pos,kStrategy strat);
 poly redtailBba_NF (poly p, kStrategy strat );
 poly redtailBba_Ring (LObject* L, int end_pos, kStrategy strat );
 poly redtailBba_Z (LObject* L, int end_pos, kStrategy strat );
 void redtailBbaAlsoLC_Z (LObject* L, int end_pos, kStrategy strat );
-#endif
 poly redtailBba (LObject *L, int end_pos,kStrategy strat,
                  BOOLEAN withT = FALSE,BOOLEAN normalize=FALSE);
 poly redtailBbaBound (LObject *L, int end_pos,kStrategy strat,int bound,
@@ -510,7 +507,6 @@ poly redNFTail (poly h,const int sl,kStrategy strat);
 int redHoney (LObject* h, kStrategy strat);
 int redHoneyM (LObject* h, kStrategy strat);
 int redLiftstd (LObject* h, kStrategy strat);
-#ifdef HAVE_RINGS
 int redRing (LObject* h,kStrategy strat);
 int redRing_Z (LObject* h,kStrategy strat);
 int redRiloc (LObject* h,kStrategy strat);
@@ -518,7 +514,6 @@ void enterExtendedSpoly(poly h,kStrategy strat);
 void enterExtendedSpolySig(poly h,poly hSig,kStrategy strat);
 void superenterpairs (poly h,int k,int ecart,int pos,kStrategy strat, int atR = -1);
 void superenterpairsSig (poly h,poly hSig,int hFrom,int k,int ecart,int pos,kStrategy strat, int atR = -1);
-#endif
 int redLazy (LObject* h,kStrategy strat);
 int redHomog (LObject* h,kStrategy strat);
 int redSig (LObject* h,kStrategy strat);
@@ -529,7 +524,7 @@ void enterpairs (poly h, int k, int ec, int pos,kStrategy strat, int atR = -1);
 void entersets (LObject h);
 void pairs ();
 BOOLEAN sbaCheckGcdPair (LObject* h,kStrategy strat);
-void message (int i,int* reduc,int* olddeg,kStrategy strat,int red_result);
+void message (int i,int* olddeg,int* reduc,kStrategy strat,int red_result);
 void messageStat (int hilbcount,kStrategy strat);
 void messageStatSBA (int hilbcount,kStrategy strat);
 #ifdef KDEBUG
@@ -557,14 +552,12 @@ void updateS(BOOLEAN toT,kStrategy strat);
 void enterSyz (LObject &p,kStrategy strat, int atT);
 void enterT (LObject &p,kStrategy strat, int atT = -1);
 void replaceInLAndSAndT(LObject &p, int tj, kStrategy strat);
-#ifdef HAVE_RINGS
 void enterT_strong (LObject &p,kStrategy strat, int atT = -1);
-#endif
 void cancelunit (LObject* p,BOOLEAN inNF=FALSE);
 void HEckeTest (poly pp,kStrategy strat);
 void initBuchMoraCrit(kStrategy strat);
 void initSbaCrit(kStrategy strat);
-void initHilbCrit(ideal F, ideal Q, intvec **hilb,kStrategy strat);
+void initHilbCrit(ideal F, ideal Q, bigintmat **hilb,kStrategy strat);
 void initBuchMoraPos(kStrategy strat);
 void initBuchMoraPosRing(kStrategy strat);
 void initSbaPos(kStrategy strat);
@@ -598,6 +591,7 @@ int kFindInTShift(poly p, TSet T, int tlength);
 /// return -1 if no divisor is found
 ///        number of first divisor in T, otherwise
 int kFindDivisibleByInT(const kStrategy strat, const LObject* L, const int start=0);
+int kFindDivisibleByInT_ecart(const kStrategy strat, const LObject* L, const int ecart);
 int kFindDivisibleByInT_Z(const kStrategy strat, const LObject* L, const int start=0);
 int kFindSameLMInT_Z(const kStrategy strat, const LObject* L, const int start=0);
 
@@ -635,10 +629,8 @@ KINLINE poly k_LmShallowCopyDelete_tailRing_2_currRing(poly p, ring tailRing);
 // return FALSE and m1 == NULL, m2 == NULL     , otherwise
 KINLINE BOOLEAN k_GetLeadTerms(const poly p1, const poly p2, const ring p_r,
                                poly &m1, poly &m2, const ring m_r);
-#ifdef HAVE_RINGS
 KINLINE void k_GetStrongLeadTerms(const poly p1, const poly p2, const ring leadRing,
                                poly &m1, poly &m2, poly &lcm, const ring taiRing);
-#endif
 #ifdef KDEBUG
 // test strat
 BOOLEAN kTest(kStrategy strat);
@@ -661,14 +653,25 @@ BOOLEAN kTest_S(kStrategy strat);
 #endif
 
 
+/***************************************************************
+ *
+ * From kstd1.cc
+ *
+ ***************************************************************/
+int redFirst (LObject* h,kStrategy strat);
+int redEcart (LObject* h,kStrategy strat);
+void enterSMora (LObject &p,int atS,kStrategy strat, int atR=-1);
+void enterSMoraNF (LObject &p,int atS,kStrategy strat, int atR=-1);
+
+
 /***************************************************************
  *
  * From kstd2.cc
  *
  ***************************************************************/
 poly kFindZeroPoly(poly input_p, ring leadRing, ring tailRing);
-ideal bba (ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat);
-ideal sba (ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat);
+ideal bba (ideal F, ideal Q,intvec *w,bigintmat *hilb,kStrategy strat);
+ideal sba (ideal F, ideal Q,intvec *w,bigintmat *hilb,kStrategy strat);
 poly kNF2 (ideal F, ideal Q, poly q, kStrategy strat, int lazyReduce);
 ideal kNF2 (ideal F,ideal Q,ideal q, kStrategy strat, int lazyReduce);
 poly kNF2Bound (ideal F, ideal Q, poly q,int bound, kStrategy strat, int lazyReduce);
@@ -677,7 +680,7 @@ void initBba(kStrategy strat);
 void initSba(ideal F,kStrategy strat);
 void f5c (kStrategy strat, int& olddeg, int& minimcnt, int& hilbeledeg,
           int& hilbcount, int& srmax, int& lrmax, int& reduc, ideal Q,
-          intvec *w,intvec *hilb );
+          intvec *w,bigintmat *hilb );
 
 /***************************************************************
  *
@@ -810,7 +813,6 @@ KINLINE void ksOldSpolyTail(poly p1, poly q, poly q2, poly spNoether, ring r = c
 //             exponent bound of strat->tailRing
 //      FALSE, otherwise
 BOOLEAN kCheckSpolyCreation(LObject* L, kStrategy strat, poly &m1, poly &m2);
-#ifdef HAVE_RINGS
 // return TRUE if gcdpoly creation of R[atR] and S[atS] does not violate
 //             exponent bound of strat->tailRing
 //      FALSE, otherwise
@@ -819,7 +821,6 @@ poly preIntegerCheck(ideal F, ideal Q);
 void postReduceByMon(LObject* h, kStrategy strat);
 void postReduceByMonSig(LObject* h, kStrategy strat);
 void finalReduceByMon(kStrategy strat);
-#endif
 // change strat->tailRing and adjust all data in strat, L, and T:
 // new tailRing has larger exponent bound
 // do nothing and return FALSE if exponent bound increase would result in
@@ -869,7 +870,7 @@ poly redtailBbaShift (LObject* L, int pos, kStrategy strat, BOOLEAN withT, BOOLE
 
 int redFirstShift (LObject* h,kStrategy strat); // ok
 
-ideal bbaShift(ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat);
+ideal bbaShift(ideal F, ideal Q,intvec *w,bigintmat *hilb,kStrategy strat);
 #endif
 
 // test syz strategy: // will be removed soon
@@ -881,11 +882,9 @@ static inline void kDeleteLcm(LObject *P)
 {
  if (P->lcm!=NULL)
  {
- #ifdef HAVE_RINGS
    if (rField_is_Ring(currRing))
      pLmDelete(P->lcm);
    else
- #endif
      pLmFree(P->lcm);
    P->lcm=NULL;
  }
