@@ -6,10 +6,9 @@
 */
 #ifndef RINGGB_HEADER
 #define RINGGB_HEADER
-// #include <kernel/mod2.h>
+// #include "kernel/mod2.h"
 
-#ifdef HAVE_RINGS
-#include <kernel/polys.h>
+#include "kernel/polys.h"
 
 poly ringNF(poly f, ideal G, ring r);
 poly plain_spoly(poly f, poly g);
@@ -19,4 +18,3 @@ poly reduce_poly_fct(poly p, ring r);
 poly ringRedNF(poly f, ideal G, ring r);
 
 #endif
-#endif
