@@ -82,8 +82,8 @@ void addLObject(LObject& h, kStrategy& strat)
     pos=0;
 
     if (strat->sl!=-1) pos = posInS(strat, strat->sl, h.p, h.ecart);
-    strat->enterS(h, pos, strat, -1);
-//    enterT(h, strat); // ?!
+    strat->enterS(&h, pos, strat, -1);
+//    enterT(&h, strat); // ?!
 
     kDeleteLcm(&h);
   }
@@ -92,7 +92,7 @@ void addLObject(LObject& h, kStrategy& strat)
 }
 
 
-ideal k_sca_gr_bba(const ideal F, const ideal Q, const intvec *, const intvec *, kStrategy strat, const ring _currRing)
+ideal k_sca_gr_bba(const ideal F, const ideal Q, const intvec *, const bigintmat *, kStrategy strat, const ring _currRing)
 {
   const ring save = currRing;
   if( currRing != _currRing ) rChangeCurrRing(_currRing);
@@ -365,7 +365,7 @@ ideal k_sca_gr_bba(const ideal F, const ideal Q, const intvec *, const intvec *,
 ///////////////////////////////////////////////////////////////////////////////////////
 
 // Under development!!!
-ideal k_sca_bba (const ideal F, const ideal Q, const intvec */*w*/, const intvec * /*hilb*/, kStrategy strat, const ring _currRing)
+ideal k_sca_bba (const ideal F, const ideal Q, const intvec */*w*/, const bigintmat * /*hilb*/, kStrategy strat, const ring _currRing)
 {
   const ring save = currRing;
   if( currRing != _currRing ) rChangeCurrRing(_currRing);
@@ -470,13 +470,6 @@ ideal k_sca_bba (const ideal F, const ideal Q, const intvec */*w*/, const intvec
   if(!idIs0(F) &&(!rField_is_Ring()))  // create strong gcd poly computes with tailring and S[i] ->to be fixed
     kStratInitChangeTailRing(strat);
 #endif
-  if (BVERBOSE(23))
-  {
-    if (test_PosInT!=NULL) strat->posInT=test_PosInT;
-    if (test_PosInL!=NULL) strat->posInL=test_PosInL;
-    kDebugPrint(strat);
-  }
-
 
   ///////////////////////////////////////////////////////////////
   // SCA:
@@ -668,14 +661,14 @@ ideal k_sca_bba (const ideal F, const ideal Q, const intvec */*w*/, const intvec
       //if(withT)
       {
         strat->P.SetpFDeg();
-        enterT(strat->P, strat);
+        enterT(&strat->P, strat);
       }
 
       // L
       enterpairs(strat->P.p,strat->sl,strat->P.ecart,pos,strat, strat->tl);
 
       // posInS only depends on the leading term
-      strat->enterS(strat->P, pos, strat, strat->tl);
+      strat->enterS(&strat->P, pos, strat, strat->tl);
 
 //       if (hilb!=NULL) khCheck(Q,w,hilb,hilbeledeg,hilbcount,strat);
 
@@ -882,7 +875,7 @@ static BOOLEAN kMoraUseBucket(kStrategy)
 }
 
 // ideal sca_mora (ideal F, ideal Q, intvec *w, intvec *, kStrategy strat)
-ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec *, kStrategy strat, const ring _currRing)
+ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const bigintmat *, kStrategy strat, const ring _currRing)
 {
   const ring save = currRing;
   if( currRing != _currRing ) rChangeCurrRing(_currRing);
@@ -918,29 +911,8 @@ ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec
   initBuchMoraPos(strat);
   //Shdl=
     initBuchMora(tempF, tempQ, strat); // temp Q, F!
-//   if (TEST_OPT_FASTHC) missingAxis(&strat->lastAxis,strat);
   // updateS in initBuchMora has Hecketest
   // * and could have put strat->kHEdgdeFound FALSE
-#if 0
-  if (ppNoether!=NULL)
-  {
-    strat->kHEdgeFound = TRUE;
-  }
-  if (strat->kHEdgeFound && strat->update)
-  {
-    firstUpdate(strat);
-    updateLHC(strat);
-    reorderL(strat);
-  }
-  if (TEST_OPT_FASTHC && (strat->lastAxis) && strat->posInLOldFlag)
-  {
-    strat->posInLOld = strat->posInL;
-    strat->posInLOldFlag = FALSE;
-    strat->posInL = posInL10;
-    updateL(strat);
-    reorderL(strat);
-  }
-#endif
   strat->use_buckets = kMoraUseBucket(strat);
 
   kTest_TS(strat);
@@ -1098,11 +1070,11 @@ ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec
         strat->P.pCleardenom();
 
       // put in T
-      enterT(strat->P,strat);
+      enterT(&strat->P,strat);
       // build new pairs
       enterpairs(strat->P.p,strat->sl,strat->P.ecart,0,strat, strat->tl);
       // put in S
-      strat->enterS(strat->P,
+      strat->enterS(&strat->P,
                     posInS(strat,strat->sl,strat->P.p, strat->P.ecart),
                     strat, strat->tl);
 
