@@ -385,11 +385,13 @@ void syMinimizeResolvente(resolvente res, int length, int first)
     syMinStep(res[syzIndex-1],res[syzIndex]);
   if (!idIs0(res[0]))
     idMinEmbedding(res[0],TRUE);
+  if((length>0) && (res[length]!=NULL) && idIs0(res[length]))
+    idDelete(&res[length]);
 }
 
 /*2
 * resolution of ideal/module arg, <=maxlength steps, (r[0..maxlength])
-*   no limitation in length if maxlength==0
+*   no limitation in length if maxlength==-1
 * input:arg
 *       minim: TRUE means mres cmd, FALSE nres cmd.
 *       if *len!=0: module weights: weights[0]
@@ -409,7 +411,6 @@ resolvente syResolvente(ideal arg, int maxlength, int * length,
   int i,k,syzIndex = 0,j,rk_arg=si_max(1,(int)id_RankFreeModule(arg,currRing));
   int Kstd1_OldDeg=Kstd1_deg;
   BOOLEAN completeMinim;
-  BOOLEAN oldDegBound=TEST_OPT_DEGBOUND;
   BOOLEAN setRegularity=TRUE;
   int wlength=*length;
 
@@ -598,8 +599,6 @@ resolvente syResolvente(ideal arg, int maxlength, int * length,
   if (w !=NULL) delete w;
 
   Kstd1_deg=Kstd1_OldDeg;
-  if (!oldDegBound)
-    si_opt_1 &= ~Sy_bit(OPT_DEGBOUND);
 
   for (i=1; i<=syzIndex; i++)
   {
@@ -673,6 +672,11 @@ syStrategy syResolution(ideal arg, int maxlength,intvec * w, BOOLEAN minim)
       fr1[i] = fr[i];
     fr[i] = NULL;
   }
+  for (int i=result->length-1;i>0;i--)
+  {
+    if (fr1[i]!=NULL)
+      fr1[i]->rank=IDELEMS(fr1[i-1]);
+  }
   omFreeSize((ADDRESS)fr,(result->length)*sizeof(ideal));
 
 #ifdef HAVE_PLURAL
@@ -774,10 +778,10 @@ void syDetect(ideal id,int index,int rsmin, BOOLEAN homog,
 }
 
 /*2
-* computes the betti numbers from a given resolution
-* of length 'length' (0..length-1), not necessairily minimal,
+* computes the Betti numbers from a given resolution
+* of length 'length' (0..length-1), not necessarily minimal,
 * (if weights are given, they are used)
-* returns the int matrix of betti numbers
+* returns the int matrix of Betti numbers
 * and the regularity
 */
 intvec * syBetti(resolvente res,int length, int * regularity,
@@ -1222,3 +1226,66 @@ syStrategy syMinimizeCopy(syStrategy org)
   result=syMinimize(result);
   return result;
 }
+
+void syFix(syStrategy r)
+{
+  if (r->fullres==NULL)
+  {
+    if(r->minres==NULL)
+    {
+      return;
+    }
+  }
+  int found=-1;
+  for(int i=1;i<r->length;i++)
+  {
+    // search (0)
+    if((r->fullres!=NULL) && (r->fullres[i]!=NULL))
+    {
+      if (idIs0(r->fullres[i])) {found=i;break;}
+    }
+    if((r->fullres!=NULL) && (r->fullres[i]==NULL)) 
+      break;
+    if((r->minres!=NULL) && (r->minres[i]!=NULL))
+    {
+      if (idIs0(r->minres[i])) {found=i;break;}
+    }
+    if((r->minres!=NULL) && (r->minres[i]==NULL))
+      break;
+  }
+  if (found>0) // delete trailing stuff
+  {
+    for(int i=found+1;i<r->length;i++)
+    {
+      if ((r->fullres!=NULL) && (r->fullres[i]!=NULL))
+        id_Delete(&r->fullres[i],currRing);
+      if ((r->minres!=NULL) && (r->minres[i]!=NULL))
+        id_Delete(&r->minres[i],currRing);
+    }
+    r->list_length=found;
+  }
+  else
+  {
+    // append (0)
+    for(int i=1;i<r->length;i++)
+    {
+      if ((r->fullres!=NULL) && (r->fullres[i]==NULL))
+      {
+        r->fullres[i]=idInit(1,IDELEMS(r->fullres[i-1]));
+        if ((r->minres!=NULL) && (r->minres[i-1]==NULL))
+	{
+	  r->minres[i]=idInit(1,IDELEMS(r->minres[i-1]));
+	}
+	break;
+      }
+      else
+      {
+        if ((r->minres!=NULL) && (r->minres[i]==NULL))
+	{
+	  r->minres[i]=idInit(1,IDELEMS(r->minres[i-1]));
+	  break;
+	}
+      }
+    }
+  }
+}
