@@ -326,7 +326,7 @@ static ideal sySchreyersSyzygiesFM(ideal arg,intvec ** modcomp)
 */
 //Print("toRed now (neuer ecart %d): ",ecartToRed);pWrite(toRed);
           notFound = TRUE;
-          bestEcart = 32000;  //a very large integer
+          bestEcart = INT_MAX-2;  //a very large integer
           p = NULL;
           int l=0;
 #define OLD_SEARCH
@@ -869,7 +869,7 @@ resolvente sySchreyerResolvente(ideal arg, int maxlength, int * length,
     return NULL;
   }
   *length = 4;
-  resolvente res = (resolvente)omAlloc0(4*sizeof(ideal)),newres;
+  resolvente res = (resolvente)omAlloc0((*length)*sizeof(ideal)),newres;
   res[0] = idCopy(arg);
 
   while ((!idIs0(res[syzIndex])) && ((maxlength==-1) || (syzIndex<maxlength)))
@@ -1018,6 +1018,8 @@ resolvente sySchreyerResolvente(ideal arg, int maxlength, int * length,
 syStrategy sySchreyer(ideal arg, int maxlength)
 {
   int rl;
+  BOOLEAN inf_length=(maxlength==0);
+  if (inf_length) maxlength=rVar(currRing)+2;
   resolvente fr = sySchreyerResolvente(arg,maxlength,&(rl));
   if (fr==NULL) return NULL;
 
@@ -1067,6 +1069,37 @@ syStrategy sySchreyer(ideal arg, int maxlength)
       idDelete(&result->fullres[rl-1]);
     }
   }
+  if (inf_length)
+  {
+    int i=0;
+    loop
+    {
+      if(result->fullres[i]!=NULL)
+      {
+        if(idIs0(result->fullres[i])) // delete everything after pos i
+        {
+          for(int j=i+1;j<=rl;j++)
+          {
+            if(result->fullres[j]!=NULL) idDelete(&result->fullres[j]);
+          }
+          rl=i;
+          break;
+        }
+      }
+      i++;
+      if (i>rl) break;
+    }
+    result->length=rl;
+    if (!idIs0(result->fullres[rl])) // add trailing 0-ideal
+    {
+      if(result->fullres[rl+1]==NULL)
+      {
+        result->fullres[rl+1]=idInit(1,1);
+        result->length=rl+1;
+      }
+    }
+  }
+
   omFreeSize((ADDRESS)fr,(rl /*result->length*/)*sizeof(ideal));
   return result;
 }
