@@ -7,12 +7,9 @@
 * ABSTRACT
 */
 
-class intvec;
-
-struct ip_sring  ; typedef struct ip_sring                          * ring;
-struct sip_sideal; typedef struct sip_sideal                        * ideal;
-struct spolyrec  ; typedef struct spolyrec polyrec; typedef polyrec * poly;
-typedef                                                     poly    * polyset;
+#include "polys/monomials/ring.h"
+#include "kernel/polys.h"
+#include "misc/intvec.h"
 
 typedef int * scmon;
 typedef scmon * scfmon;
@@ -37,17 +34,18 @@ struct sindlist
 
 #define LEN_MON (sizeof(scfmon) + sizeof(int))
 
-extern omBin indlist_bin;
+EXTERN_VAR omBin indlist_bin;
 
-extern scfmon hexist, hstc, hrad, hwork;
-extern scmon hpure, hpur0;
-extern varset hvar, hsel;
-extern int hNexist, hNstc, hNrad, hNvar, hNpure;
-extern monf stcmem, radmem;
-extern int hisModule;
-extern monf stcmem, radmem;
-extern indset ISet, JSet;
-extern int  hCo, hMu, hMu2;
+EXTERN_VAR scfmon hexist, hstc, hrad, hwork;
+EXTERN_VAR scmon hpure, hpur0;
+EXTERN_VAR varset hvar, hsel;
+EXTERN_VAR int hNexist, hNstc, hNrad, hNvar, hNpure;
+EXTERN_VAR monf stcmem, radmem;
+EXTERN_VAR int hisModule;
+EXTERN_VAR monf stcmem, radmem;
+EXTERN_VAR indset ISet, JSet;
+EXTERN_VAR int  hCo, hMu2;
+EXTERN_VAR long  hMu;
 
 
 void hDelete(scfmon ev, int ev_length);
@@ -81,7 +79,7 @@ void hIndAllMult(scmon pure, int Npure, scfmon rad, int Nrad,
 void hDegreeSeries(intvec *s1, intvec *s2, int *co, int *mu);
 
 
-scfmon hInit(ideal S, ideal Q, int * Nexist, ring tailRing);
-void slicehilb(ideal I);
-void HilbertSeries_OrbitData(ideal S, int lV, bool ig, bool mgrad, bool odp);
+scfmon hInit(ideal S, ideal Q, int * Nexist);
+void HilbertSeries_OrbitData(ideal S, int lV, bool ig, bool mgrad, bool odp, int trunDegHs);
+ideal  RightColonOperation(ideal i, poly w, int lV);
 #endif
