@@ -35,7 +35,7 @@
 #include "kernel/combinatorics/stairc.h"
 #include "factory/templates/ftmpl_list.h"
 
-// obachman: Got rid off those "redefiende messages by includeing fglm.h
+// obachman: Got rid of those "redefined" messages by including fglm.h
 #include "fglm.h"
 #if 0
 #define PROT(msg) if (BTEST1(OPT_PROT)) Print(msg)
@@ -107,7 +107,7 @@ int
 hfglmNextdegree( intvec * source, ideal current, int & deg )
 {
     int numelems;
-    intvec * newhilb = hHstdSeries( current, NULL, currRing->qideal );
+    intvec * newhilb = hFirstSeries( current, NULL, currRing->qideal );
 
     loop
     {
@@ -222,7 +222,7 @@ mapMonoms( ring oldRing, homogData & dat )
     int s;
     for ( s= dat.numMonoms - 1; s >= 0; s-- ) {
 //        dat.monlist[s].mon.sm= pPermPoly( dat.monlist[s].mon.dm, vperm, currRing->N, NULL, 0 );
-      // obachman: changed the folowing to reflect the new calling interface of
+      // obachman: changed the following to reflect the new calling interface of
       // pPermPoly -- Tim please check whether this is correct!
         dat.monlist[s].mon.sm= pPermPoly( dat.monlist[s].mon.dm, vperm, oldRing, NULL, 0 );
     }
@@ -349,7 +349,7 @@ fglmhomog( ring sourceRing, ideal sourceIdeal, ring destRing, ideal & destIdeal
     // get the hilbert series and the leading monomials of the sourceIdeal:
     rChangeCurrRing( sourceRing );
 
-    intvec * hilb = hHstdSeries( sourceIdeal, NULL, currRing->qideal );
+    intvec * hilb = hFirstSeries( sourceIdeal, NULL, currRing->qideal );
     int s;
     dat.sourceIdeal= sourceIdeal;
     dat.sourceHeads= (doublepoly *)omAlloc( IDELEMS( sourceIdeal ) * sizeof( doublepoly ) );
