@@ -220,13 +220,16 @@ int MinorProcessor::IOverJ(const int i, const int j)
   /* This is a non-recursive implementation. */
   assume( (i >= 0) && (j >= 0) && (i >= j));
   if (j == 0 || i == j) return 1;
+  #if 0
   int result = 1;
   for (int k = i - j + 1; k <= i; k++) result *= k;
   /* Now, result = (i - j + 1) * ... * i. */
   for (int k = 2; k <= j; k++) result /= k;
   /* Now, result = (i - j + 1) * ... * i / 1 / 2 ...
-     ... / j = i! / j! / (i - j)!. */
+   ... / j = i! / j! / (i - j)!. */
   return result;
+  #endif
+  return binom(i,j);
 }
 
 int MinorProcessor::Faculty(const int i)
@@ -615,7 +618,7 @@ IntMinorValue IntMinorProcessor::getMinorPrivateBareiss(
         rowPermutation[i] = rowPermutation[r];
         rowPermutation[r] = j;
         /* Now we know that tempMatrix[rowPermutation[r] * k + r] is not zero.
-           But carefull; we have to negate the sign, as there is always an odd
+           But careful; we have to negate the sign, as there is always an odd
            number of row transpositions to swap two given rows of a matrix. */
         sign = -sign;
       }
@@ -1470,7 +1473,7 @@ PolyMinorValue PolyMinorProcessor::getMinorPrivateBareiss(const int k,
         rowPermutation[bestRow] = rowPermutation[r];
         rowPermutation[r] = j;
         /* Now we know that tempMatrix[rowPermutation[r] * k + r] is not zero.
-           But carefull; we have to negate the sign, as there is always an odd
+           But careful; we have to negate the sign, as there is always an odd
            number of row transpositions to swap two given rows of a matrix. */
         sign = -sign;
       }
