@@ -431,7 +431,7 @@ ideal fast_map_common_subexp(const ideal map_id,const ring map_r,const ideal ima
 * Evaluation stuff                                                    *
 **********************************************************************/
 
-// substitute p everywhere the monomial occours,
+// substitute p everywhere the monomial occurs,
 // return the number of substitutions
 static int maPoly_Substitute(macoeff c, poly p, ring dest_r)
 {
@@ -444,9 +444,7 @@ static int maPoly_Substitute(macoeff c, poly p, ring dest_r)
   {
     done++;
     poly t=__pp_Mult_nn(p,c->n,dest_r);
-    #ifdef HAVE_RINGS
     if (zero_div) len=pLength(t);
-    #endif
     sBucket_Add_p(c->bucket, t, len);
     c=c->next;
   }
@@ -459,21 +457,24 @@ static poly maPoly_EvalMon(poly src, ring src_r, poly* dest_id, ring dest_r)
   int e;
   poly p=NULL;
   poly pp;
-  BOOLEAN is_const=TRUE; // to check for zero-div in p_Mult_q
+  BOOLEAN is_const=TRUE; // for constant src
   for(i=1;i<=src_r->N;i++)
   {
     e=p_GetExp(src,i,src_r);
     if (e>0)
     {
-      is_const=FALSE;
       pp=dest_id[i-1];
       if (pp==NULL)
       {
         p_Delete(&p,dest_r);
         return NULL;
       }
-      if (/*(*/ p==NULL /*)*/) /* && (e>0)*/
+      if (p==NULL)
       {
+        if (!is_const) // possible only when the coefficient ring is not a field
+        {
+          return NULL;
+        }
         p=p_Copy(pp /*dest_id[i-1]*/,dest_r);
         e--;
       }
@@ -482,6 +483,7 @@ static poly maPoly_EvalMon(poly src, ring src_r, poly* dest_id, ring dest_r)
         p=p_Mult_q(p,p_Copy(pp /*dest_id[i-1]*/,dest_r),dest_r);
         e--;
       }
+      is_const=FALSE;
     }
   }
   if (is_const)
