@@ -7,14 +7,13 @@
 *  ABSTRACT - get the computing time
 */
 
-extern int timerv;
-void startTimer(void);
+EXTERN_VAR int timerv;
+int startTimer(void);
 void writeTime(const char* s);
 
-int initTimer();
-int  getTimer();
+long getTimer();
 
-extern int rtimerv;
+EXTERN_VAR int rtimerv;
 void startRTimer(void);
 void writeRTime(const char* s);
 
