@@ -397,21 +397,21 @@ ipc_signal_t check_signal(bool resume, bool lock) {
           pollfd pfd;
           pfd.fd = fd;
           pfd.events = POLLIN;
-          int rv = poll(&pfd, 1, 10000); /* msec*/
+          int rv = poll(&pfd, 1, 500000); /* msec*/
           #else
           // fd is restricted to <=1024
           fd_set set;
           FD_ZERO(&set); /* clear the set */
           FD_SET(fd, &set); /* add our file descriptor to the set */
           struct timeval timeout;
-          timeout.tv_sec = 10;
+          timeout.tv_sec = 500;
           timeout.tv_usec = 0;
           int rv = si_select(fd + 1, &set, NULL, NULL, &timeout);
           #endif
           if (rv== -1) continue; /* an error occurred */
           if (rv== 0) break;  /* timeout */
-          //while(read(fd, buf, 1)!=1) {}
-          if(read(fd, buf, 1)==1) break;
+          while(read(fd, buf, 1)!=1) {}
+          break;
         }
         lock_process(vmem.current_process);
       } else {
@@ -422,21 +422,21 @@ ipc_signal_t check_signal(bool resume, bool lock) {
           pollfd pfd;
           pfd.fd = fd;
           pfd.events = POLLIN;
-          int rv = poll(&pfd, 1, 10000); /* msec*/
+          int rv = poll(&pfd, 1, 500000); /* msec*/
           #else
           // fd is restricted to <=1024
           fd_set set;
           FD_ZERO(&set); /* clear the set */
           FD_SET(fd, &set); /* add our file descriptor to the set */
           struct timeval timeout;
-          timeout.tv_sec = 10;
+          timeout.tv_sec = 500;
           timeout.tv_usec = 0;
           int rv = si_select(fd + 1, &set, NULL, NULL, &timeout);
           #endif
           if (rv== -1) continue;  /* an error occurred */
           if (rv== 0) break;  /* timeout */
-          //while(read(fd, buf, 1)!=1) {}
-          if(read(fd, buf, 1)==1) break;
+          while(read(fd, buf, 1)!=1) {}
+          break;
         }
       }
       result = process_info(vmem.current_process).signal;
@@ -1006,21 +1006,21 @@ ipc_signal_t check_signal(bool resume, bool lock) {
           pollfd pfd;
           pfd.fd = fd;
           pfd.events = POLLIN;
-          int rv = poll(&pfd, 1, 10000); /* msec*/
+          int rv = poll(&pfd, 1, 500000); /* msec*/
           #else
           // fd is restricted to <=1024
           fd_set set;
           FD_ZERO(&set); /* clear the set */
           FD_SET(fd, &set); /* add our file descriptor to the set */
           struct timeval timeout;
-          timeout.tv_sec = 10;
+          timeout.tv_sec = 500;
           timeout.tv_usec = 0;
           int rv = si_select(fd + 1, &set, NULL, NULL, &timeout);
           #endif
           if (rv== -1) continue;  /* an error occurred */
           if (rv== 0) break;  /* timeout */
-          //while(read(fd, buf, 1)!=1) {}
-          if(read(fd, buf, 1)==1) break;
+          while(read(fd, buf, 1)!=1) {}
+          break;
         }
         lock_process(vmem.current_process);
       } else {
@@ -1031,21 +1031,21 @@ ipc_signal_t check_signal(bool resume, bool lock) {
           pollfd pfd;
           pfd.fd = fd;
           pfd.events = POLLIN;
-          int rv = poll(&pfd, 1, 10000); /* msec*/
+          int rv = poll(&pfd, 1, 500000); /* msec*/
           #else
           // fd is restricted to <=1024
           fd_set set;
           FD_ZERO(&set); /* clear the set */
           FD_SET(fd, &set); /* add our file descriptor to the set */
           struct timeval timeout;
-          timeout.tv_sec = 10;
+          timeout.tv_sec = 500;
           timeout.tv_usec = 0;
           int rv = si_select(fd + 1, &set, NULL, NULL, &timeout);
           #endif
           if (rv== -1) continue; /* an error occurred */
           if (rv== 0) break;/* timeout */
-          //while(read(fd, buf, 1)!=1) {}
-          if(read(fd, buf, 1)==1) break;
+          while(read(fd, buf, 1)!=1) {}
+          break;
         }
       }
       result = process_info(vmem.current_process).signal;
