@@ -8,20 +8,13 @@
 */
 
 #include "kernel/mod2.h"
+
 /* for omBin */
 #include "omalloc/omalloc.h"
-#ifdef HAVE_RINGS
-#include "coeffs/si_gmp.h"
-#endif
-
-/* standard types */
-#define BITSET  unsigned int
-
 
 /* C++-part */
 #ifdef __cplusplus
 #include "kernel/polys.h"
-#include "polys/coeffrings.h"
 
 class Voice;
 class sleftv;
@@ -77,7 +70,7 @@ typedef procinfo *         procinfov;
 
 #define loop for(;;)
 
-extern omBin char_ptr_bin;
+EXTERN_VAR omBin char_ptr_bin;
 
 #endif
 
