@@ -26,33 +26,33 @@ class CanonicalForm;
 enum n_coeffType
 {
   n_unknown=0,
-  n_Zp, /**< \F{p < 2^31} */
-  n_Q,  /**< rational (GMP) numbers */
-  n_R,  /**< single prescision (6,6) real numbers */
-  n_GF, /**< \GF{p^n < 2^16} */
-  n_long_R, /**< real floating point (GMP) numbers */
-  n_polyExt, /**< used to represent polys as coeffcients */
-  n_algExt,  /**< used for all algebraic extensions, i.e.,
+  n_Zp=1, /**< \F{p < 2^31} */
+  n_Q=2,  /**< rational (GMP) numbers */
+  n_R=3,  /**< single prescision (6,6) real numbers */
+  n_GF=4, /**< \GF{p^n < 2^16} */
+  n_long_R=5, /**< real floating point (GMP) numbers */
+  n_polyExt=6, /**< used to represent polys as coefficients */
+  n_algExt=7,  /**< used for all algebraic extensions, i.e.,
                 the top-most extension in an extension tower
                 is algebraic */
-  n_transExt,  /**< used for all transcendental extensions, i.e.,
+  n_transExt=8,  /**< used for all transcendental extensions, i.e.,
                   the top-most extension in an extension tower
                   is transcendental */
-  n_long_C, /**< complex floating point (GMP) numbers */
-  n_nTupel, /**< n-tupel of cf: ZZ/p1,... ZZ/pn, R, long_R */
-  n_Z, /**< only used if HAVE_RINGS is defined  */
-  n_Zn, /**< only used if HAVE_RINGS is defined */
-  n_Znm, /**< only used if HAVE_RINGS is defined */
-  n_Z2m, /**< only used if HAVE_RINGS is defined */
-  n_FlintQrat, /**< rational funtion field over Q */
-  n_CF, /**< ? */
-  n_Nemo_AnticNumberField, /*17 */
-  n_Nemo_QQField,          /*18 */
-  n_Nemo_ZZRing,           /*19*/
-  n_Nemo_FqPolyRepField,   /*20 */
-  n_Nemo_fqPolyRepField,   /*21 */
-  n_Nemo_Field,            /*22 */
-  n_Nemo_Ring              /*23 */
+  n_long_C=9, /**< complex floating point (GMP) numbers */
+  n_nTupel=10, /**< n-tupel of cf: ZZ/p1,... ZZ/pn, R, long_R */
+  n_Z=11, /**< only used if HAVE_RINGS is defined  */
+  n_Zn=12, /**< only used if HAVE_RINGS is defined */
+  n_Znm=13, /**< only used if HAVE_RINGS is defined */
+  n_Z2m=14, /**< only used if HAVE_RINGS is defined */
+  n_FlintQrat=15, /**< rational function field over Q */
+  n_CF=16, /**< ? */
+  n_Nemo_AnticNumberField=17, /*17 */
+  n_Nemo_QQField=18,          /*18 */
+  n_Nemo_ZZRing=19,           /*19*/
+  n_Nemo_FqPolyRepField=20,   /*20 */
+  n_Nemo_fqPolyRepField=21,   /*21 */
+  n_Nemo_Field=22,            /*22 */
+  n_Nemo_Ring=23              /*23 */
 };
 
 extern const unsigned short fftable[];
@@ -157,7 +157,7 @@ struct n_Procs_s
    /// string output of coeff description
    char* (*cfCoeffString)(const coeffs r);
 
-   /// default name of cf, should substitue cfCoeffWrite, cfCoeffString
+   /// default name of cf, should substitute cfCoeffWrite, cfCoeffString
    char* (*cfCoeffName)(const coeffs r);
 
    // ?
@@ -178,7 +178,7 @@ struct n_Procs_s
    //
    //   cfDiv does an exact division, but has to handle illegal input
    //   cfExactDiv does an exact division, but no error checking
-   //   (I'm not sure I understant and even less that this makes sense)
+   //   (I'm not sure I understand and even less that this makes sense)
    numberfunc cfMult, cfSub ,cfAdd ,cfDiv, cfIntMod, cfExactDiv;
 
    /// init with an integer
@@ -190,7 +190,7 @@ struct n_Procs_s
    /// how complicated, (0) => 0, or positive
    int     (*cfSize)(number n, const coeffs r);
 
-   /// convertion to long, 0 if impossible
+   /// conversion to long, 0 if impossible
    long    (*cfInt)(number &n, const coeffs r);
 
    /// Converts a (integer) number n into a GMP number, 0 if impossible
@@ -270,7 +270,7 @@ struct n_Procs_s
    //return NULL if a is already normalized
    //otherwise, the factor.
    //(for Z: make positive, for z/nZ make the gcd with n
-   //aparently it is GetUnit!
+   //apparently it is GetUnit!
    //in a Euclidean ring, return the quotient and compute the remainder
    //rem can be NULL
    number  (*cfQuotRem)(number a, number b, number *rem, const coeffs r);
@@ -303,7 +303,7 @@ struct n_Procs_s
    //    strange things happen in naChineseRemainder for example.
    number  (*cfChineseRemainder)(number *x, number *q,int rl, BOOLEAN sym,CFArray &inv_cache,const coeffs);
 
-   /// degree for coeffcients: -1 for 0, 0 for "constants", ...
+   /// degree for coefficients: -1 for 0, 0 for "constants", ...
    int (*cfParDeg)(number x,const coeffs r);
 
    /// create i^th parameter or NULL if not possible
@@ -416,6 +416,8 @@ struct n_Procs_s
   /*CF: for blackbox rings, contains data needed to define the ring.
    * contents depends on the actual example.*/
   void * data;
+  number  (*cfReadFd_S)(char**s, const coeffs r);
+  void    (*cfWriteFd_S)(number a, const coeffs r);
 #ifdef LDEBUG
    // must be last entry:
    /// Test: is "a" a correct number?
@@ -530,7 +532,7 @@ static FORCE_INLINE int n_DivComp(number a, number b, const coeffs r)
 ///                                   is co-prime with k
 /// in Z/2^kZ: largest odd divisor of n (taken in Z)
 /// other cases: not implemented
-// CF: shold imply that n/GetUnit(n) is normalized in Z/kZ
+// CF: should imply that n/GetUnit(n) is normalized in Z/kZ
 //   it would make more sense to return the inverse...
 static FORCE_INLINE number n_GetUnit(number n, const coeffs r)
 { assume(r != NULL); assume(r->cfGetUnit!=NULL); return r->cfGetUnit(n,r); }
@@ -844,7 +846,7 @@ static FORCE_INLINE BOOLEAN nCoeff_is_Extension(const coeffs r)
 
 /* DO NOT USE (only kept for compatibility reasons towards the SINGULAR
    svn trunk);
-   intension: should be TRUE iff the given r is an extension field above
+   intention: should be TRUE iff the given r is an extension field above
    some Z/pZ;
    actually: TRUE iff the given r is an extension tower of arbitrary
    height above some field of characteristic p (may be Z/pZ or some
@@ -857,7 +859,7 @@ static FORCE_INLINE BOOLEAN nCoeff_is_Zp_a(const coeffs r)
 
 /* DO NOT USE (only kept for compatibility reasons towards the SINGULAR
    svn trunk);
-   intension: should be TRUE iff the given r is an extension field above
+   intention: should be TRUE iff the given r is an extension field above
    Z/pZ (with p as provided);
    actually: TRUE iff the given r is an extension tower of arbitrary
    height above some field of characteristic p (may be Z/pZ or some
@@ -871,7 +873,7 @@ static FORCE_INLINE BOOLEAN nCoeff_is_Zp_a(const coeffs r, int p)
 
 /* DO NOT USE (only kept for compatibility reasons towards the SINGULAR
    svn trunk);
-   intension: should be TRUE iff the given r is an extension field
+   intention: should be TRUE iff the given r is an extension field
    above Q;
    actually: TRUE iff the given r is an extension tower of arbitrary
    height above some field of characteristic 0 (may be Q, R, or C) */
@@ -904,13 +906,17 @@ static FORCE_INLINE BOOLEAN nCoeff_is_algExt(const coeffs r)
 { assume(r != NULL); return (getCoeffType(r)==n_algExt); }
 
 /// is it an alg. ext. of Q?
-static FORCE_INLINE BOOLEAN nCoeff_is_Q_algext(const coeffs r)
+static FORCE_INLINE BOOLEAN nCoeff_is_Q_algExt(const coeffs r)
 { assume(r != NULL); return ((n_GetChar(r) == 0) && nCoeff_is_algExt(r)); }
 
 /// TRUE iff r represents a transcendental extension field
 static FORCE_INLINE BOOLEAN nCoeff_is_transExt(const coeffs r)
 { assume(r != NULL); return (getCoeffType(r)==n_transExt); }
 
+/// is it an trans. ext. of Q?
+static FORCE_INLINE BOOLEAN nCoeff_is_Q_transExt(const coeffs r)
+{ assume(r != NULL); return ((n_GetChar(r) == 0) && nCoeff_is_transExt(r)); }
+
 /// Computes the content and (inplace) divides it out on a collection
 /// of numbers
 /// number @em c is the content (i.e. the GCD of all the coeffs, which
@@ -962,10 +968,14 @@ static FORCE_INLINE number n_Random(siRandProc p, number p1, number p2, const co
 /// io via ssi:
 static FORCE_INLINE void n_WriteFd(number a, const ssiInfo *f, const coeffs r)
 { assume(r != NULL); assume(r->cfWriteFd != NULL); return r->cfWriteFd(a, f, r); }
+static FORCE_INLINE void n_WriteFd_S(number a, const coeffs r)
+{ assume(r != NULL); assume(r->cfWriteFd_S != NULL); return r->cfWriteFd_S(a, r); }
 
 /// io via ssi:
 static FORCE_INLINE number n_ReadFd( const ssiInfo *f, const coeffs r)
 { assume(r != NULL); assume(r->cfReadFd != NULL); return r->cfReadFd(f, r); }
+static FORCE_INLINE number n_ReadFd_S(char**s, const coeffs r)
+{ assume(r != NULL); assume(r->cfReadFd_S != NULL); return r->cfReadFd_S(s, r); }
 
 
 static FORCE_INLINE number n_convFactoryNSingN( const CanonicalForm n, const coeffs r)
@@ -979,6 +989,5 @@ static FORCE_INLINE CanonicalForm n_convSingNFactoryN( number n, BOOLEAN setChar
 // the following 2 inline functions are just convenience shortcuts for Frank's code:
 static FORCE_INLINE void number2mpz(number n, coeffs c, mpz_t m){ n_MPZ(m, n, c); }
 static FORCE_INLINE number mpz2number(mpz_t m, coeffs c){ return n_InitMPZ(m, c); }
-
 #endif
 
