@@ -1,2 +1,2 @@
-extern coeffs coeffs1,coeffs2;
+EXTERN_VAR coeffs coeffs1,coeffs2;
 BOOLEAN gInitChar(coeffs r, void* p);
