@@ -1607,26 +1607,6 @@ number nlModP(number q, const coeffs /*Q*/, const coeffs Zp)
   return z;
 }
 
-/*2
-* convert number i (from Q) to GMP and warn if denom != 1
-*/
-void nlGMP(number &i, mpz_t n, const coeffs r)
-{
-  // Hier brauche ich einfach die GMP Zahl
-  nlTest(i, r);
-  nlNormalize(i, r);
-  if (SR_HDL(i) & SR_INT)
-  {
-    mpz_set_si(n, SR_TO_INT(i));
-    return;
-  }
-  if (i->s!=3)
-  {
-    WarnS("Omitted denominator during coefficient mapping !");
-  }
-  mpz_set(n, i->z);
-}
-
 /*2
 * access to denominator, other 1 for integers
 */
@@ -2815,6 +2795,15 @@ void nlMPZ(mpz_t m, number &n, const coeffs r)
   else             mpz_init_set(m, (mpz_ptr)n->z);
 }
 
+void nlMPZ2(mpz_t m, number &n, const coeffs r)
+{
+  nlTest(n, r);
+  nlNormalize(n, r);
+  if (SR_HDL(n) & SR_INT) mpz_init_set_si(m,1); /* small int*/
+  else if (n->s==3)       mpz_init_set_si(m,1); /* large int*/
+  else                    mpz_init_set(m, (mpz_ptr)n->n);
+}
+
 
 number  nlXExtGcd (number a, number b, number *s, number *t, number *u, number *v, const coeffs r)
 {
@@ -3345,7 +3334,7 @@ void nlWriteFd(number n, const ssiInfo* d, const coeffs)
   else if (n->s<2)
   {
     //gmp_fprintf(f,"%d %Zd %Zd ",n->s,n->z,n->n);
-    fprintf(d->f_write,"%d ",n->s+5);
+    fprintf(d->f_write,"%d ",n->s+5); // 5 or 6
     mpz_out_str (d->f_write,SSI_BASE, n->z);
     fputc(' ',d->f_write);
     mpz_out_str (d->f_write,SSI_BASE, n->n);
@@ -3364,6 +3353,55 @@ void nlWriteFd(number n, const ssiInfo* d, const coeffs)
   }
 }
 
+static void nlWriteFd_S(number n, const coeffs)
+{
+  if(SR_HDL(n) & SR_INT)
+  {
+    #if SIZEOF_LONG == 4
+    StringAppend("4 %ld ",SR_TO_INT(n));
+    #else
+    long nn=SR_TO_INT(n);
+    if ((nn<POW_2_28_32)&&(nn>= -POW_2_28_32))
+    {
+      int nnn=(int)nn;
+      StringAppend("4 %d ",nnn);
+    }
+    else
+    {
+      char str[30];// n< 2^64
+      mpz_t tmp;
+      mpz_init_set_si(tmp,nn);
+      StringAppendS("8 ");
+      mpz_get_str (str,SSI_BASE, tmp);
+      StringAppend("%s ",str);
+      mpz_clear(tmp);
+    }
+    #endif
+  }
+  else if (n->s<2)
+  {
+    int l=mpz_sizeinbase(n->z,SSI_BASE);
+    int l2=mpz_sizeinbase(n->n,SSI_BASE);
+    if (l2>l) l=l2;
+    char *str=(char*)omAlloc(l+2);
+    StringAppend("%d ",n->s+5); // 5 or 6
+    mpz_get_str (str,SSI_BASE, n->z);
+    StringAppend("%s ",str);
+    mpz_get_str (str,SSI_BASE, n->n);
+    StringAppend("%s ",str);
+    omFreeSize(str,l+2);
+  }
+  else /*n->s==3*/
+  {
+    int l=mpz_sizeinbase(n->z,SSI_BASE);
+    char *str=(char*)omAlloc(l+2);
+    StringAppendS("8 ");
+    mpz_get_str (str,SSI_BASE, n->z);
+    StringAppend("%s ",str);
+    omFreeSize(str,l+2);
+  }
+}
+
 number nlReadFd(const ssiInfo *d, const coeffs)
 {
   int sub_type=-1;
@@ -3394,11 +3432,7 @@ number nlReadFd(const ssiInfo *d, const coeffs)
      case 4:
        {
          LONG dd=s_readlong(d->f_read);
-         //#if SIZEOF_LONG == 8
          return INT_TO_SR(dd);
-         //#else
-         //return nlInit(dd,NULL);
-         //#endif
        }
      case 5:
      case 6:
@@ -3427,6 +3461,65 @@ number nlReadFd(const ssiInfo *d, const coeffs)
   return NULL;
 }
 
+number nlReadFd_S(char**s, const coeffs)
+{
+  int sub_type=-1;
+  sub_type=s_readint_S(s);
+  switch(sub_type)
+  {
+     case 0:
+     case 1:
+       {// read mpz_t, mpz_t
+         number n=nlRInit(0);
+         mpz_init(n->n);
+         s_readmpz_S(s,n->z);
+         s_readmpz_S(s,n->n);
+         n->s=sub_type;
+         return n;
+       }
+
+     case 3:
+       {// read mpz_t
+         number n=nlRInit(0);
+         s_readmpz_S(s,n->z);
+         n->s=3; /*sub_type*/
+         #if SIZEOF_LONG == 8
+         n=nlShort3(n);
+         #endif
+         return n;
+       }
+     case 4:
+       {
+         long dd=s_readlong_S(s);
+         return INT_TO_SR(dd);
+       }
+     case 5:
+     case 6:
+       {// read raw mpz_t, mpz_t
+         number n=nlRInit(0);
+         mpz_init(n->n);
+         s_readmpz_base_S (s,n->z, SSI_BASE);
+         s_readmpz_base_S (s,n->n, SSI_BASE);
+         n->s=sub_type-5;
+         return n;
+       }
+     case 8:
+       {// read raw mpz_t
+         number n=nlRInit(0);
+         s_readmpz_base_S (s,n->z, SSI_BASE);
+         n->s=sub_type=3; /*subtype-5*/
+         #if SIZEOF_LONG == 8
+         n=nlShort3(n);
+         #endif
+         return n;
+       }
+
+     default: Werror("error in reading number: invalid subtype %d",sub_type);
+              return NULL;
+  }
+  return NULL;
+}
+
 BOOLEAN nlCoeffIsEqual(const coeffs r, n_coeffType n, void *p)
 {
   /* test, if r is an instance of nInitCoeffs(n,parameter) */
@@ -3548,7 +3641,9 @@ BOOLEAN nlInitChar(coeffs r, void*p)
 
   // io via ssi
   r->cfWriteFd=nlWriteFd;
+  r->cfWriteFd_S=nlWriteFd_S;
   r->cfReadFd=nlReadFd;
+  r->cfReadFd_S=nlReadFd_S;
 
   //r->type = n_Q;
   r->ch = 0;
