@@ -251,7 +251,7 @@ static const char * npRead (const char *s, number *a, const coeffs r)
 }
 
 /*2
-* set the charcteristic (allocate and init tables)
+* set the characteristic (allocate and init tables)
 */
 
 void npKillChar(coeffs r)
@@ -309,6 +309,11 @@ static void npWriteFd(number n, const ssiInfo* d, const coeffs)
   fprintf(d->f_write,"%d ",(int)(long)n);
 }
 
+static void npWriteFd_S(number n, const coeffs)
+{
+  StringAppend("%d ",(int)(long)n);
+}
+
 static number npReadFd(const ssiInfo *d, const coeffs)
 {
   // read int
@@ -317,6 +322,14 @@ static number npReadFd(const ssiInfo *d, const coeffs)
   return (number)(long)dd;
 }
 
+static number npReadFd_S(char**s, const coeffs)
+{
+  // read int
+  int dd;
+  dd=s_readint_S(s);
+  return (number)(long)dd;
+}
+
 static number npRandom(siRandProc p, number, number, const coeffs cf)
 {
   return npInit(p(),cf);
@@ -404,7 +417,9 @@ BOOLEAN npInitChar(coeffs r, void* p)
 
   // io via ssi
   r->cfWriteFd=npWriteFd;
+  r->cfWriteFd_S=npWriteFd_S;
   r->cfReadFd=npReadFd;
+  r->cfReadFd_S=npReadFd_S;
 
   // the variables:
   r->type = n_Zp;
