@@ -153,6 +153,12 @@ number ndReadFd( const ssiInfo *, const coeffs r)
   return n_Init(0,r);
 }
 
+number ndReadFd_S( char**, const coeffs r)
+{
+  Warn("ReadFd_S not implemented for %s (c=%d)",r->cfCoeffName(r),getCoeffType(r));
+  return n_Init(0,r);
+}
+
 static void ndWriteFd(number, const ssiInfo *, const coeffs r)
 {
   Warn("WriteFd not implemented for %s (c=%d)",r->cfCoeffName(r),getCoeffType(r));
@@ -249,7 +255,7 @@ static void ndClearContent(ICoeffsEnumerator& numberCollectionEnumerator, number
   }
 
   assume(!nCoeff_is_Ring(r));
-  assume(nCoeff_is_Zp(r) || nCoeff_is_numeric(r) || nCoeff_is_GF(r) || nCoeff_is_Zp_a(r) || nCoeff_is_Q_algext(r));
+  assume(nCoeff_is_Zp(r) || nCoeff_is_numeric(r) || nCoeff_is_GF(r) || nCoeff_is_Zp_a(r) || nCoeff_is_Q_algExt(r));
 
   n_Normalize(curr, r); // Q: good/bad/ugly??
 
@@ -428,7 +434,7 @@ coeffs nInitChar(n_coeffType t, void * parameter)
     n->cfAnn = ndAnn;
     n->cfCoeffString = ndCoeffString;
     n->cfCoeffWrite = ndCoeffWrite;
-    n->cfCoeffName = ndCoeffName; // should alway be changed!
+    n->cfCoeffName = ndCoeffName; // should always be changed!
     n->cfInpAdd=ndInpAdd;
     n->cfInpMult=ndInpMult;
     n->cfCopy = ndCopy;
@@ -452,6 +458,7 @@ coeffs nInitChar(n_coeffType t, void * parameter)
     n->cfFarey = ndFarey; /* not implemented */
     n->cfParDeg = ndParDeg; /* not implemented */
     n->cfReadFd = ndReadFd; /* not implemented */
+    n->cfReadFd_S = ndReadFd_S; /* not implemented */
     n->cfWriteFd = ndWriteFd; /* not implemented */
 
     n->cfParameter = ndParameter;
@@ -696,10 +703,10 @@ char* nEati(char *s, long *i, int m)
       if ((m!=0) && (ii > (LONG_MAX / 10))) ii = ii % m;
     }
     while (((*s) >= '0') && ((*s) <= '9'));
-    if ((m!=0) && (ii>=(long)m)) ii=ii%m;
+    if ((m!=0) && (ii>=(unsigned long)m)) ii=ii%(unsigned long)m;
     *i=ii;
   }
-  else (*i) = 1;
+  else (*i) = 1L;
   return s;
 }
 
