@@ -20,10 +20,8 @@
 
 #include <string.h>
 
-#ifdef HAVE_RINGS
-
 #ifdef LDEBUG
-BOOLEAN nr2mDBTest(number a, const char *f, const int l, const coeffs r)
+static BOOLEAN nr2mDBTest(number a, const char *f, const int l, const coeffs r)
 {
   if ((((long)a<0L) || ((long)a>(long)r->mod2mMask))
   && (r->mod2mMask!= ~0UL))
@@ -74,11 +72,11 @@ EXTERN_VAR omBin gmp_nrz_bin; /* init in rintegers*/
 
 static char* nr2mCoeffName(const coeffs cf)
 {
-  STATIC_VAR char n2mCoeffName_buf[30];
+  STATIC_VAR char n2mCoeffName_buf[37];
   if (cf->modExponent>32) /* for 32/64bit arch.*/
-    snprintf(n2mCoeffName_buf,21,"ZZ/(bigint(2)^%lu)",cf->modExponent);
+    snprintf(n2mCoeffName_buf,36,"ZZ/(bigint(2)^%lu)",cf->modExponent);
   else
-    snprintf(n2mCoeffName_buf,21,"ZZ/(2^%lu)",cf->modExponent);
+    snprintf(n2mCoeffName_buf,36,"ZZ/(2^%lu)",cf->modExponent);
   return n2mCoeffName_buf;
 }
 
@@ -487,9 +485,11 @@ static BOOLEAN nr2mDivBy (number a, number b, const coeffs r)
   }
 }
 
-static BOOLEAN nr2mGreater(number a, number b, const coeffs r)
+static BOOLEAN nr2mGreater(number as, number bs, const coeffs r)
 {
-  return nr2mDivBy(a, b,r);
+  unsigned long a = (unsigned long)as;
+  unsigned long b = (unsigned long)bs;
+  return (a > b);
 }
 
 static int nr2mDivComp(number as, number bs, const coeffs)
@@ -855,6 +855,3 @@ BOOLEAN nr2mInitChar (coeffs r, void* p)
   r->has_simple_Alloc=TRUE;
   return FALSE;
 }
-
-#endif
-/* #ifdef HAVE_RINGS */
