@@ -7,7 +7,7 @@
 * ABSTRACT
 */
 #include "misc/auxiliary.h"
-#include "omalloc/omalloc.h" /* for SIZEOF_DOUBLE */
+#include "omalloc/omalloc.h"
 
 #if SIZEOF_DOUBLE == SIZEOF_LONG
 #define SI_FLOAT double
