@@ -68,7 +68,7 @@ EXTERN_VAR BOOLEAN siCntrlc;
 #define V_INTERSECT_ELIM 25
 #define V_INTERSECT_SYZ  26
 #define V_ASSIGN_NONE    27
-#define V_NOT_TRICKS     28
+#define V_PURE_GB        28
 /* for tests: 28-30 */
 #define V_DEG_STOP       31
 
@@ -134,7 +134,7 @@ EXTERN_VAR BOOLEAN siCntrlc;
 #define TEST_V_NSB                 BVERBOSE(V_NSB)
 #define TEST_V_QUIET               BVERBOSE(V_QUIET)
 #define TEST_V_ASSIGN_NONE         BVERBOSE(V_ASSIGN_NONE)
-#define TEST_V_NOT_TRICKS          BVERBOSE(V_NOT_TRICKS)
+#define TEST_V_PURE_GB             BVERBOSE(V_PURE_GB)
 
 #define TEST_VERB_NSB              BVERBOSE(V_NSB)
 #define TEST_V_DEG_STOP            BVERBOSE(V_DEG_STOP)
