@@ -3,10 +3,10 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int siSeed;
-int siRand();
+EXTERN_VAR int siSeed;
+int siRand(void);
 
-typedef int (*siRandProc)();
+typedef int (*siRandProc)(void);
 typedef int (*siRandProc1)(int);
 int siRandNext(int);
 int siRandPlus1(int);
