@@ -367,7 +367,7 @@ poly Flint_GCD_MP(poly p,int lp,poly q,int lq,fmpq_mpoly_ctx_t ctx,const ring r)
   {
     // Flint normalizes the gcd to be monic.
     // Singular wants a gcd defined over ZZ that is primitive and has a positive leading coeff.
-    if (!fmpq_mpoly_is_zero(res, ctx))
+    //if (!fmpq_mpoly_is_zero(res, ctx))
     {
       fmpq_t content;
       fmpq_init(content);
