@@ -25,10 +25,10 @@
  **/
 
 #ifdef HAVE_FLINT
-#include <flint/flint.h>
 
 #include "polys/matpol.h"
 #include "coeffs/bigintmat.h"
+#include <flint/flint.h>
 #include <flint/fmpz.h>
 #include <flint/fmpq.h>
 #include <flint/fmpq_mat.h>
@@ -42,6 +42,9 @@
 #include <flint/fq_nmod.h>
 #include <flint/fq_nmod_poly.h>
 #include <flint/fq_nmod_mat.h>
+#include <flint/nmod_poly.h>
+#include <flint/nmod_mat.h>
+#include <flint/fmpz_mat.h>
 #endif
 
 int convFlintISingI (fmpz_t f);
