@@ -28,7 +28,7 @@ void kBucketDeleteAndDestroy(kBucket_pt *bucket);
 
 
 /////////////////////////////////////////////////////////////////////////////
-// Convertion from/to Bpolys
+// Conversion from/to Bpolys
 //
 
 // Converts p into a bucket poly (Bpoly) and destroys p
@@ -47,10 +47,13 @@ inline poly kBucketClear(kBucket_pt bucket)
   return p;
 }
 
-// Canonicalizes Bpoly, i.e. converts polys of buckets into one poly in
-// one bucket: Returns number of bucket into which it is canonicalized
+/// Canonicalizes Bpoly, i.e. converts polys of buckets into one poly in
+/// one bucket: Returns number of bucket into which it is canonicalized
 int kBucketCanonicalize(kBucket_pt bucket);
 
+/// apply n_Normalize to all coefficients
+void kBucketNormalize(kBucket_pt bucket);
+
 /////////////////////////////////////////////////////////////////////////////
 // Extracts lm of Bpoly, i.e. Bpoly is changed s.t.
 // Bpoly == Bpoly - Lm(Bpoly)
@@ -80,6 +83,10 @@ void kBucketAdjust(kBucket_pt bucket, int i);
 number kBucketPolyRed(kBucket_pt bucket,
                       poly p, int l,
                       poly spNoether);
+void kBucketPolyRedNF(kBucket_pt bucket,
+                      poly p1, int l1,
+                      poly spNoether);
+
 
 
 /////////////////////////////////////////////////////////////////////////////
