@@ -631,6 +631,7 @@ void mp_Coef2(poly v, poly mon, matrix *c, matrix *m, const ring R)
     }
     v = v->next;
   }
+  omFree(s);
 }
 
 int mp_Compare(matrix a, matrix b, const ring R)
@@ -1788,6 +1789,8 @@ matrix mp_Wedge(matrix a, int ar, const ring R)
     for (j=1; j<=ar; j++) MATELEM(tmp,i,j) = NULL;
   }
   id_Delete((ideal *) &tmp, R);
+  omFree(colchoise);
+  omFree(rowchoise);
   return (result);
 }
 
