@@ -13,6 +13,7 @@
 #include "misc/intvec.h"
 #include "misc/int64vec.h"
 #include "coeffs/coeffs.h" // ring,number
+#include "coeffs/bigintmat.h" // bigintmat
 #include "polys/monomials/monomials.h"
 //#include "polys/monomials/polys-impl.h"
 //
@@ -46,7 +47,7 @@ typedef poly (*pShallowCopyDeleteProc)(poly s_p, ring source_r, ring dest_r,
 
 // ro_typ describes what to store at the corresping "data" place in p->exp
 // none of the directly corresponds to a ring ordering (ringorder_*)
-// as each ringorder_* blocks corrsponds to 0..2 sro-blocks
+// as each ringorder_* blocks corresponds to 0..2 sro-blocks
 typedef enum
 {
   ro_dp, // total degree with weights 1
@@ -195,7 +196,7 @@ typedef struct sro_syz sro_syz;
 
 // due to prefix/suffix nature we need some placeholder:
 // prefix stores here initial state
-// suffix cleares this up
+// suffix clears this up
 struct sro_ISTemp
 {
   short start; // 1st member SHOULD be short "place"
@@ -203,8 +204,8 @@ struct sro_ISTemp
   int*  pVarOffset; // copy!
 };
 
-// So this is the actuall thing!
-// suffix uses last sro_ISTemp (cleares it up afterwards) and
+// So this is the actual thing!
+// suffix uses last sro_ISTemp (clears it up afterwards) and
 // creates this block
 struct sro_IS
 {
@@ -246,7 +247,7 @@ class skStrategy;
 typedef skStrategy * kStrategy;
 
 typedef poly (*NF_Proc)(ideal, ideal, poly, int, int, const ring _currRing);
-typedef ideal (*BBA_Proc) (const ideal, const ideal, const intvec *, const intvec *, kStrategy strat, const ring);
+typedef ideal (*BBA_Proc) (const ideal, const ideal, const intvec *, const bigintmat *, kStrategy strat, const ring);
 
 
 struct ip_sring
@@ -270,7 +271,7 @@ struct ip_sring
   sro_ord*   typ;   /* array of orderings + sizes, OrdSize entries */
   /* if NegWeightL_Size > 0, then NegWeightL_Offset[0..size_1] is index of longs
   in ExpVector whose values need an offset due to negative weights */
-  /* array of NegWeigtL_Size indicies */
+  /* array of NegWeigtL_Size indices */
   int*      NegWeightL_Offset;
 
   int*     VarOffset;
@@ -756,6 +757,7 @@ int rGetMaxSyzComp(int i, const ring r);
 
 BOOLEAN rHasSimpleOrder(const ring r);
 BOOLEAN rHas_c_Ordering(const ring r);
+BOOLEAN rHasBlockOrder(const ring r);
 
 /// returns TRUE, if simple lp or ls ordering
 BOOLEAN rHasSimpleLexOrder(const ring r);
@@ -763,9 +765,9 @@ BOOLEAN rHasSimpleLexOrder(const ring r);
 //???? return TRUE if p->exp[r->pOrdIndex] holds total degree of p ???
 
 
-inline BOOLEAN rHasGlobalOrdering(const ring r){ return (r->OrdSgn==1); }
-inline BOOLEAN rHasLocalOrMixedOrdering(const ring r){ return (r->OrdSgn==-1); }
-inline BOOLEAN rHasMixedOrdering(const ring r) { return (r->MixedOrder); }
+static inline BOOLEAN rHasGlobalOrdering(const ring r){ return (r->OrdSgn==1); }
+static inline BOOLEAN rHasLocalOrMixedOrdering(const ring r){ return (r->OrdSgn==-1); }
+static inline BOOLEAN rHasMixedOrdering(const ring r) { return (r->MixedOrder); }
 
 // #define rHasGlobalOrdering(R) ((R)->OrdSgn==1)
 // #define rHasLocalOrMixedOrdering(R) ((R)->OrdSgn==-1)
@@ -773,6 +775,7 @@ inline BOOLEAN rHasMixedOrdering(const ring r) { return (r->MixedOrder); }
 BOOLEAN rOrd_is_Totaldegree_Ordering(const ring r);
 BOOLEAN rOrd_is_dp(const ring r);
 BOOLEAN rOrd_is_ds(const ring r);
+BOOLEAN rOrd_is_Ds(const ring r);
 
 /// return TRUE if p_SetComp requires p_Setm
 BOOLEAN rOrd_SetCompRequiresSetm(const ring r);
@@ -817,7 +820,7 @@ int64 * rGetWeightVec(const ring r);
 void rSetWeightVec(ring r, int64 *wv);
 
 /////////////////////////////
-// Auxillary functions
+// Auxiliary functions
 //
 
 /* return the varIndex-th ring variable as a poly;
