@@ -58,7 +58,7 @@
 
 static poly NF_Proc_Dummy(ideal, ideal, poly, int, int, const ring)
 { WerrorS("nc_NF not defined"); return NULL; }
-static ideal BBA_Proc_Dummy (const ideal, const ideal, const intvec *, const intvec *, kStrategy, const ring)
+static ideal BBA_Proc_Dummy (const ideal, const ideal, const intvec *, const bigintmat *, kStrategy, const ring)
 { WerrorS("nc_NF not defined"); return NULL; }
 
 // the following function pointers are quasi-static:
@@ -121,7 +121,7 @@ poly gnc_ReduceSpolyNew(const poly p1, poly p2/*, poly spNoether*/, const ring r
 
 
 
-static void gnc_kBucketPolyRedNew(kBucket_pt b, poly p, number *c, BOOLEAN reduce);
+static void gnc_kBucketPolyRedNew(kBucket_pt b, poly p, number *c, BOOLEAN);
 static void gnc_kBucketPolyRed_ZNew(kBucket_pt b, poly p, number *c, BOOLEAN reduce);
 
 void gnc_kBucketPolyRedOld(kBucket_pt b, poly p, number *c);
@@ -1945,7 +1945,7 @@ void gnc_kBucketPolyRedOld(kBucket_pt b, poly p, number *c)
   kBucket_Add_q(b,pp,&l);
 }
 
-void gnc_kBucketPolyRedNew(kBucket_pt b, poly p, number *c, BOOLEAN reduce)
+static void gnc_kBucketPolyRedNew(kBucket_pt b, poly p, number *c, BOOLEAN)
 {
   const ring r = b->bucket_ring;
 #ifdef PDEBUG
