@@ -5,7 +5,7 @@
 *  Computer Algebra System SINGULAR     *
 ****************************************/
 /*
-* ABSTRACT: accces single (coeffs of) monoms
+* ABSTRACT: access single (coeffs of) monoms
 */
 
 #include "misc/auxiliary.h"
@@ -33,6 +33,6 @@ ideal id_CoeffTermV(ideal M, poly m, const ring r);
 /// find coeffs of a vector of a list of given monomials, n>=max_comp(v)
 poly p_CoeffTermId(poly v, ideal m, int n, const ring r);
 
-/// find coeffs of a vector of a matrix(as module) of given monomials, n>=max_comp(v)
-poly p_CoeffTermMo(poly v, ideal m, int n, const ring r);
+/// find coeffs of a vector of a matrix(as module) of given monomials
+poly p_CoeffTermMo(poly v, ideal m, const ring r);
 #endif
