@@ -8,7 +8,6 @@
 
 #include "misc/auxiliary.h"
 
-#include "omalloc/omalloc.h"
 #include "polys/monomials/ring.h"
 #include "polys/monomials/p_polys.h"
 #include "coeffs/numbers.h"
@@ -64,6 +63,7 @@ poly prMapR(poly src, nMapFunc nMap, ring src_r, ring dest_r)
     if (n_IsZero(pGetCoeff(dest),dest_r->cf))
     {
       p_LmDelete(&pNext(prev),dest_r);
+      dest=prev;
     }
     pIter(src);
   }
