@@ -37,7 +37,7 @@ bool sIsEmpty(const sBucket_pt bucket);
 
 
 /////////////////////////////////////////////////////////////////////////////
-// Convertion from/to SBpolys
+// Conversion from/to SBpolys
 //
 
 // Converts p into a bucket poly (SBpoly) and destroys p
@@ -57,14 +57,14 @@ void sBucketClearMerge(sBucket_pt bucket, poly *p, int *length);
 // bucket may contain equal monials
 void sBucketClearAdd(sBucket_pt bucket, poly *p, int *length);
 
-// Converts SBpoly into a poly and detroys bucket
+// Converts SBpoly into a poly and destroys bucket
 inline void sBucketDestroyMerge(sBucket_pt bucket, poly *p, int *length)
 {
   sBucketClearMerge(bucket, p, length);
   sBucketDestroy(&bucket);
 }
 
-// Converts SBpoly into a poly and detroys bucket
+// Converts SBpoly into a poly and destroys bucket
 inline void sBucketDestroyAdd(sBucket_pt bucket, poly *p, int *length)
 {
   sBucketClearAdd(bucket, p, length);
@@ -73,6 +73,7 @@ inline void sBucketDestroyAdd(sBucket_pt bucket, poly *p, int *length)
 
 void sBucketDeleteAndDestroy(sBucket_pt *bucket_pt);
 
+poly sBucketPeek(sBucket_pt b);
 //////////////////////////////////////////////////////////////////////////
 
 /// Merges p into Spoly: assumes Bpoly and p have no common monoms
@@ -99,4 +100,8 @@ poly sBucketSortMerge(poly p, const ring r);
 poly sBucketSortAdd(poly p, const ring r);
 
 
+//////////////////////////////////////////////////////////////////////////
+void sBucketCanonicalize(sBucket_pt bucket);
+char* sBucketString(sBucket_pt bucket);
+void sBucketPrint(sBucket_pt bucket);
 #endif // P_BUCKET_SORT
