@@ -200,37 +200,38 @@ void id_ShallowDelete (ideal *h, ring r)
 /// gives an ideal/module the minimal possible size
 void idSkipZeroes (ideal ide)
 {
-  assume (ide != NULL);
-
-  int k;
-  int j = -1;
-  int idelems=IDELEMS(ide);
-  BOOLEAN change=FALSE;
-
-  for (k=0; k<idelems; k++)
+  if(ide!=NULL)
   {
-    if (ide->m[k] != NULL)
+    int k;
+    int j = -1;
+    int idelems=IDELEMS(ide);
+    BOOLEAN change=FALSE;
+  
+    for (k=0; k<idelems; k++)
     {
-      j++;
-      if (change)
+      if (ide->m[k] != NULL)
       {
-        ide->m[j] = ide->m[k];
-        ide->m[k] = NULL;
+        j++;
+        if (change)
+        {
+          ide->m[j] = ide->m[k];
+          ide->m[k] = NULL;
+        }
+      }
+      else
+      {
+        change=TRUE;
       }
     }
-    else
+    if (change)
     {
-      change=TRUE;
+      if (j == -1)
+        j = 0;
+      j++;
+      pEnlargeSet(&(ide->m),idelems,j-idelems);
+      IDELEMS(ide) = j;
     }
   }
-  if (change)
-  {
-    if (j == -1)
-      j = 0;
-    j++;
-    pEnlargeSet(&(ide->m),idelems,j-idelems);
-    IDELEMS(ide) = j;
-  }
 }
 
 int idSkipZeroes0 (ideal ide) /*idSkipZeroes without realloc*/
@@ -958,9 +959,7 @@ ideal  id_Mult (ideal h1,ideal  h2, const ring R)
 /// returns true if h is the zero ideal
 BOOLEAN idIs0 (ideal h)
 {
-  assume (h != NULL); // will fail :(
-
-  if (h->m!=NULL)
+  if ((h!=NULL) && (h->m!=NULL))
   {
     for( int i = IDELEMS(h)-1; i >= 0; i-- )
       if(h->m[i] != NULL)
@@ -1987,7 +1986,8 @@ void id_Normalize(ideal I,const ring r) /* for ideal/matrix */
   int i;
   for(i=I->nrows*I->ncols-1;i>=0;i--)
   {
-    p_Normalize(I->m[i],r);
+    poly p=I->m[i];
+    if (p!=NULL) p_Normalize(p,r);
   }
 }
 
