@@ -6,14 +6,8 @@
 * ABSTRACT:
 */
 
-
-
-
-
 #include "misc/auxiliary.h"
 
-#include "omalloc/omalloc.h"
-
 #include "misc/options.h"
 #include "misc/intvec.h"
 
@@ -23,19 +17,19 @@
 #include "polys/weight.h"
 
 /*0 implementation*/
-extern "C" double (*wFunctional)(int *degw, int *lpol, int npol,
+extern "C" THREAD_VAR double (*wFunctional)(int *degw, int *lpol, int npol,
        double *rel, double wx, double wNsqr);
-extern "C" double wFunctionalMora(int *degw, int *lpol, int npol,
+double wFunctionalMora(int *degw, int *lpol, int npol,
        double *rel, double wx, double wNsqr);
-extern "C" double wFunctionalBuch(int *degw, int *lpol, int npol,
+double wFunctionalBuch(int *degw, int *lpol, int npol,
        double *rel, double wx, double wNsqr);
-extern "C" void wAdd(int *A, int mons, int kn, int xx, int rvar);
-extern "C" void wNorm(int *degw, int *lpol, int npol, double *rel);
-extern "C" void wFirstSearch(int *A, int *x, int mons,
+void wAdd(int *A, int mons, int kn, int xx, int rvar);
+void wNorm(int *degw, int *lpol, int npol, double *rel);
+void wFirstSearch(int *A, int *x, int mons,
         int *lpol, int npol, double *rel, double *fopt, double wNsqr, int rvar);
-extern "C" void wSecondSearch(int *A, int *x, int *lpol,
+void wSecondSearch(int *A, int *x, int *lpol,
         int npol, int mons, double *rel, double *fk, double wNsqr, int rvar);
-extern "C" void wGcd(int *x, int n);
+void wGcd(int *x, int n);
 
 static void wDimensions(poly* s, int sl, int *lpol, int *npol, int *mons)
 {
@@ -203,9 +197,9 @@ void kEcartWeights(poly* s, int sl, short *eweight, const ring R)
   omFreeSize((ADDRESS)x, 2 * (n + 1) * sizeof(int));
 }
 
-short * iv2array(intvec * iv, const ring R)
+int * iv2array(intvec * iv, const ring R)
 {
-  short *s=(short *)omAlloc0((rVar(R)+1)*sizeof(short));
+  int *s=(int *)omAlloc0((rVar(R)+1)*sizeof(int));
   int len=0;
   if(iv!=NULL)
     len=si_min(iv->length(),rVar(R)); // usually: rVar(R)==length()
@@ -234,7 +228,7 @@ long totaldegreeWecart(poly p, ring r)
 *computes the degree of the leading term of the polynomial
 *with respect to given weights
 */
-long totaldegreeWecart_IV(poly p, ring r, const short *w)
+long totaldegreeWecart_IV(poly p, ring r, const int *w)
 {
   int i;
   long j =0;
