@@ -9,7 +9,7 @@
 
 #include "polys/monomials/ring.h"
 
-extern short * ecartWeights;
+EXTERN_VAR short * ecartWeights;
 //extern pFDegProc pFDegOld;
 //extern pLDegProc pLDegOld;
 
@@ -18,14 +18,14 @@ void kEcartWeights(poly* s, int sl, short *eweight, const ring R);
 //BOOLEAN kQHWeight(leftv res,leftv v);
 long maxdegreeWecart(poly p,int *l, ring r);
 long totaldegreeWecart(poly p, ring r);
-long totaldegreeWecart_IV(poly p, ring r, const short *w);
+long totaldegreeWecart_IV(poly p, ring r, const int *w);
 
-short * iv2array(intvec * iv, const ring R);
+int * iv2array(intvec * iv, const ring R);
 
 // internal:
-extern "C" double (*wFunctional)(int *degw, int *lpol, int npol,
+extern "C" THREAD_VAR double (*wFunctional)(int *degw, int *lpol, int npol,
        double *rel, double wx, double wNsqr);
-extern "C" double wFunctionalBuch(int *degw, int *lpol, int npol,
+double wFunctionalBuch(int *degw, int *lpol, int npol,
        double *rel, double wx, double wNsqr);
 void wCall(poly* s, int sl, int *x, double wNsqr, const ring R);
 
