@@ -6,16 +6,18 @@
  *  Author:  obachman@mathematik.uni-kl.de (Olaf Bachmann)
  *  Created: 11/99
  *******************************************************************/
+#include "omalloc/omConfig.h"
 
+#ifdef HAVE_OMALLOC
 #define malloc      omMallocFunc
 #define calloc      omCallocFunc
 #define free        omFreeFunc
 #define freeSize    omFreeSizeFunc
 #define realloc     omReallocFunc
 #define reallocSize omReallocSizeFunc
-#define memalign    omMemalignFunc
 #define strdup      omStrdupFunc
 #define valloc      omVallocFunc
 
 #define OMALLOC_FUNC
 #include <omalloc/omalloc.c>
+#endif
