@@ -4,7 +4,7 @@
  *  Author:  obachman@mathematik.uni-kl.de (Olaf Bachmann)
  *  Created: 11/99
  *******************************************************************/
-#include <mylimits.h>
+#include <limits.h>
 #include <stdarg.h>
 
 #include "omalloc.h"
@@ -409,7 +409,8 @@ omError_t omReportAddrError(omError_t error, omError_t report_error, void* addr,
   omReportError(error, report_error, OM_FLR_VAL, fmt, ap);
   om_CallErrorHook = 1;
 
-  _omPrintAddrInfo(stderr, error, addr, bin_size, flags, 10, " occurred for");
+  if ((error!=omError_NotBinAddr)&&(error!=omError_FreedAddr))
+    _omPrintAddrInfo(stderr, error, addr, bin_size, flags, 10, " occurred for");
   om_Opts.ErrorHook();
 
   om_Opts.MaxCheck = max_check;
@@ -417,24 +418,31 @@ omError_t omReportAddrError(omError_t error, omError_t report_error, void* addr,
   return om_ErrorStatus;
 }
 
-void _omPrintAddrInfo(FILE* fd, omError_t error, void* addr, void* bin_size, omTrackFlags_t flags, int frames, const char* s)
+static void _omPrintAddrInfo(FILE* fd, omError_t error, void* addr, void* bin_size, omTrackFlags_t flags, int frames, const char* s)
 {
   int x;
-  if (! (x=omCheckPtr(addr, omError_MaxError, OM_FLR)))
+  if ((! (x=omCheckPtr(addr, omError_MaxError, OM_FLR)))
+  ||(x==omError_UnalignedAddr))
   {
     fprintf(fd, "%s addr:%p size:%ld", s, addr, (long)omSizeOfAddr(addr));
 
-  if (error == omError_WrongSize && (flags & OM_FSIZE))
-    fprintf(fd, " specified size:%ld", (long) bin_size);
+    if (error == omError_UnalignedAddr)
+      fputs(" unaligned",fd);
 
-  if (error == omError_WrongBin && (flags & OM_FBIN))
-    fprintf(fd, " specified bin is of size:%ld",
+    if (error == omError_WrongSize && (flags & OM_FSIZE))
+      fprintf(fd, " specified size:%ld", (long) bin_size);
+
+    if (error == omError_WrongBin && (flags & OM_FBIN))
+      fprintf(fd, " specified bin is of size:%ld",
                  (long)((omBin) bin_size)->sizeW << LOG_SIZEOF_LONG);
 
-  if (omIsTrackAddr(addr))
-    omPrintTrackAddrInfo(fd, addr, frames);
-  else
-    fprintf(fd, "\n");
+    if (omIsTrackAddr(addr))
+      omPrintTrackAddrInfo(fd, addr, frames);
+    else
+    {
+      fputs(" !omIsTrackAddr\n",fd);
+      omPrintTrackAddrInfo(fd, addr, frames);
+    }
   }
   else
   {
@@ -549,7 +557,7 @@ static void _omPrintUsedAddr(void* addr)
     if (om_print_frames > 0)
     {
       _omPrintAddrInfo(om_print_used_addr_fd, omError_NoError, addr, NULL, 0, om_print_frames, "");
-      fprintf(om_print_used_addr_fd, "\n");
+      fputc('\n',om_print_used_addr_fd);
     }
   }
 }
