@@ -32,8 +32,8 @@ static const struct omErrorString_s om_ErrorStrings[] =
   {omError_FalseAddr,                   "omError_FalseAddr",                   "addr not as returned by omalloc"},
   {omError_FalseAddrOrMemoryCorrupted,  "omError_FalseAddrOrMemoryCorrupted",  "addr not as returned by omalloc or memory corrupted", },
   {omError_WrongSize,                   "omError_WrongSize",                   "wrong size specification of addr"},
-  {omError_FreedAddr,                   "omError_FreedAddr",                   "addr had previosuly been freed"},
-  {omError_FreedAddrOrMemoryCorrupted,  "omError_FreedAddrOrMemoryCorrupted",  "addr had previosuly been freed  or memory corrupted"},
+  {omError_FreedAddr,                   "omError_FreedAddr",                   "addr had previously been freed"},
+  {omError_FreedAddrOrMemoryCorrupted,  "omError_FreedAddrOrMemoryCorrupted",  "addr had previously been freed  or memory corrupted"},
   {omError_WrongBin,                    "omError_WrongBin",                    "addr is not from given Bin"},
   {omError_UnknownBin,                  "omError_UnknownBin",                  "given Bin is unknown"},
   {omError_NotBinAddr,                  "omError_NotBinAddr",                  "addr is not a BinAddr"},
