@@ -11,11 +11,18 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "omalloc/omConfig.h"
+#ifndef HAVE_OMALLOC
+#include "omalloc/xalloc.h"
+#else
+
 #ifdef __cplusplus
 extern "C" {
   #if __cplusplus >= 201402L
   /* clang 3.7, gcc 5.1 sets 201402L */
   #define REGISTER
+  #elif defined(__clang__)
+  #define REGISTER
   #else
   #define REGISTER register
   #endif
@@ -23,11 +30,12 @@ extern "C" {
   #define REGISTER register
 #endif
 
-#include "omalloc/omConfig.h"
+extern int om_sing_opt_show_mem;
 
 #if defined(OM_NDEBUG) && !defined(OM_ALLOC_INTERNAL)
 #if (SIZEOF_LONG == 8)
 #define OM_T_FREE1
+#define OM_T_FREE2
 #define OM_T_FREE3
 #define OM_T_STR
 #define OM_T_ALLOC
@@ -59,4 +67,5 @@ extern "C" {
 }
 #endif
 
+#endif /* HAVE_OMALLOC */
 #endif /* OM_ALLOC_H */
