@@ -9,8 +9,9 @@
 
 #include <new>
 #include <stdlib.h>
+#include "omalloc/omConfig.h"
+#ifdef HAVE_OMALLOC
 #include "omalloc/omallocClass.h"
-
 // The C++ standard has ratified a change to the new operator.
 //
 //  T *p = new T;
@@ -45,3 +46,4 @@ void *  omallocClass::operator new[](size_t size, const std::nothrow_t &) throw(
   return addr;
 }
 #endif
+#endif
